//  File: SCANalone4Wrap.cs
//-----------------------------------------------------------------------------
//  Copyright (c) 2018 by SCANLAB GmbH.                    All rights reserved.
//-----------------------------------------------------------------------------
//
//
//  Abstract
//      Defines the SCANalone4Wrap class that imports SCANalone4 functions
//      from SCANalone4's dynamic-link library.
//      SCANalone4Wrap automatically selects SCANalone4s 64-bit version
//      SCANalone4x64.dll, if the 64-bit runtime is in use. Otherwise, the
//      32-bit version SCANalone4.DLL is going to be selected. That is,
//      SCANalone4Wrap is good to compile for the platform targets x86, x64,
//      or 'Any CPU', where the application, which is compiled for 'Any CPU',
//      is able to run under 32-bit or 64-bit operating systems, as well.
//
//  Author
//      Christian Lutz, Bernhard Schrems
//
//      This file was automatically generated on Mrz 28, 2018.
//
//  NOTE
//      THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
//      KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
//      IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR
//      PURPOSE.
//
//-----------------------------------------------------------------------------
using System;
using System.Runtime.InteropServices;

namespace SCANalone4Import
{
    /// <summary>
    /// Static SCANalone4 Wrapper class.
    /// Notice that the construction of the SCANalone4Wrap object or an initial
    /// call of any SCANalone4Wrap method may throw a TypeInitializationException
    /// exception, which indicates that the required DLL is missing or the
    /// import of a particular DLL function failed. In order to analyze and
    /// properly handle such an error condition you need to catch that
    /// TypeInitializationException type exception.
    /// </summary>
    public class SCANalone4Wrap
    {
        const int SampleArraySize = 32768;

        const string SCANalone4x86 = "SCANalone4.dll";     // DLL's 32-bit version.
        const string SCANalone4x64 = "SCANalone4x64.dll";  // DLL's 64-bit version.

        class FunctionImporter
        {
            static string SCANalone4;

            [DllImport("Kernel32.dll")]
            private extern static IntPtr LoadLibrary(string path);

            [DllImport("kernel32.dll")]
            public extern static bool FreeLibrary(IntPtr hModule);

            [DllImport("Kernel32.dll")]
            private extern static IntPtr GetProcAddress(IntPtr hModule,
                                                        string procName);

            static IntPtr hModule;

            static FunctionImporter instance = null;

            protected FunctionImporter(string DllName)
            {
                hModule = LoadLibrary(DllName);
            }

            ~FunctionImporter()
            {
                if (hModule != IntPtr.Zero)
                    FreeLibrary(hModule);
            }

            public static Delegate Import<T>(string functionName)
            {
                if (instance == null)
                {
                    SCANalone4= (Marshal.SizeOf(typeof(IntPtr)) == 4) ? SCANalone4x86 : SCANalone4x64;
                    instance = new FunctionImporter(SCANalone4);

                    if (hModule == IntPtr.Zero)
                        throw new System.IO.
                                FileNotFoundException(SCANalone4 + " not found. ");
                }
                var functionAddress = GetProcAddress(hModule, functionName);
                try
                {
                    return Marshal.
                        GetDelegateForFunctionPointer(functionAddress, typeof(T));
                }
                catch (Exception ex)
                {
                    if ((ex is ArgumentException) || (ex is ArgumentNullException))
                        throw new EntryPointNotFoundException(functionName);
                    else throw;
                }
            }
        }

        #region SCANalone4FunctionDelegates
        public delegate ushort scanalone_count_cardsDelegate();
        public delegate void select_rtcDelegate(ushort n);
        public delegate int n_usb_statusDelegate(ushort n);
        public delegate int usb_statusDelegate();
        public delegate short n_load_correction_fileDelegate(ushort n, string filename, short cortable, double kx, double ky, double phi, double xoffset, double yoffset);
        public delegate short load_correction_fileDelegate(string filename, short cortable, double kx, double ky, double phi, double xoffset, double yoffset);
        public delegate short n_load_corDelegate(ushort n, string filename);
        public delegate short load_corDelegate(string filename);
        public delegate void n_stop_executionDelegate(ushort n);
        public delegate short n_load_program_fileDelegate(ushort n, string name);
        public delegate short load_program_fileDelegate(string name);
        public delegate short n_load_proDelegate(ushort n, string filename);
        public delegate short load_proDelegate(string filename);
        public delegate short n_load_varpolydelayDelegate(ushort n, string stbfilename, ushort tableno);
        public delegate short load_varpolydelayDelegate(string stbfilename, ushort tableno);
        public delegate short n_load_z_tableDelegate(ushort n, double a, double b, double c);
        public delegate short load_z_tableDelegate(double a, double b, double c);
        public delegate void n_get_waveformDelegate(ushort n, ushort channel, ushort stopp, [MarshalAs(UnmanagedType.LPArray, SizeConst=SampleArraySize)] short[] memptr);
        public delegate void get_waveformDelegate(ushort channel, ushort stopp, [MarshalAs(UnmanagedType.LPArray, SizeConst=SampleArraySize)] short[] memptr);
        public delegate void n_get_statusDelegate(ushort n, out ushort busy, out int position);
        public delegate void get_statusDelegate(out ushort busy, out int position);
        public delegate ushort n_read_statusDelegate(ushort n);
        public delegate ushort read_statusDelegate();
        public delegate ushort get_dll_versionDelegate();
        public delegate int n_get_input_pointerDelegate(ushort n);
        public delegate int get_input_pointerDelegate();
        public delegate void n_set_input_pointerDelegate(ushort n, int pointer);
        public delegate void set_input_pointerDelegate(int pointer);
        public delegate void n_set_start_list_1Delegate(ushort n);
        public delegate void set_start_list_1Delegate();
        public delegate void n_set_start_list_2Delegate(ushort n);
        public delegate void set_start_list_2Delegate();
        public delegate void n_set_start_listDelegate(ushort n, ushort listno);
        public delegate void set_start_listDelegate(ushort listno);
        public delegate void n_execute_list_1Delegate(ushort n);
        public delegate void execute_list_1Delegate();
        public delegate void n_execute_list_2Delegate(ushort n);
        public delegate void execute_list_2Delegate();
        public delegate void n_execute_listDelegate(ushort n, ushort listno);
        public delegate void execute_listDelegate(ushort listno);
        public delegate void n_write_8bit_portDelegate(ushort n, ushort value);
        public delegate void write_8bit_portDelegate(ushort value);
        public delegate void n_write_io_portDelegate(ushort n, ushort value);
        public delegate void write_io_portDelegate(ushort value);
        public delegate void n_auto_changeDelegate(ushort n);
        public delegate void auto_changeDelegate();
        public delegate void n_aut_changeDelegate(ushort n);
        public delegate void aut_changeDelegate();
        public delegate void n_start_loopDelegate(ushort n);
        public delegate void start_loopDelegate();
        public delegate void n_quit_loopDelegate(ushort n);
        public delegate void quit_loopDelegate();
        public delegate void stop_executionDelegate();
        public delegate void n_dsp_startDelegate(ushort n);
        public delegate void dsp_startDelegate();
        public delegate ushort n_read_io_portDelegate(ushort n);
        public delegate ushort read_io_portDelegate();
        public delegate void n_write_da_1Delegate(ushort n, ushort value);
        public delegate void write_da_1Delegate(ushort value);
        public delegate void n_write_da_2Delegate(ushort n, ushort value);
        public delegate void write_da_2Delegate(ushort value);
        public delegate void n_write_da_xDelegate(ushort n, ushort x, ushort value);
        public delegate void write_da_xDelegate(ushort x, ushort value);
        public delegate void n_set_max_countsDelegate(ushort n, int counts);
        public delegate void set_max_countsDelegate(int counts);
        public delegate int n_get_countsDelegate(ushort n);
        public delegate int get_countsDelegate();
        public delegate void n_set_matrixDelegate(ushort n, double m11, double m12, double m21, double m22);
        public delegate void set_matrixDelegate(double m11, double m12, double m21, double m22);
        public delegate void n_set_offsetDelegate(ushort n, short xoffset, short yoffset);
        public delegate void set_offsetDelegate(short xoffset, short yoffset);
        public delegate void n_goto_xyDelegate(ushort n, short x, short y);
        public delegate void goto_xyDelegate(short x, short y);
        public delegate void n_goto_xyzDelegate(ushort n, short x, short y, short z);
        public delegate void goto_xyzDelegate(short x, short y, short z);
        public delegate ushort n_get_hex_versionDelegate(ushort n);
        public delegate ushort get_hex_versionDelegate();
        public delegate void n_enable_laserDelegate(ushort n);
        public delegate void enable_laserDelegate();
        public delegate void n_disable_laserDelegate(ushort n);
        public delegate void disable_laserDelegate();
        public delegate void n_stop_listDelegate(ushort n);
        public delegate void stop_listDelegate();
        public delegate void n_restart_listDelegate(ushort n);
        public delegate void restart_listDelegate();
        public delegate ushort n_get_rtc_versionDelegate(ushort n);
        public delegate ushort get_rtc_versionDelegate();
        public delegate void n_get_xy_posDelegate(ushort n, out short x, out short y);
        public delegate void get_xy_posDelegate(out short x, out short y);
        public delegate void n_get_xyz_posDelegate(ushort n, out short x, out short y, out short z);
        public delegate void get_xyz_posDelegate(out short x, out short y, out short z);
        public delegate void n_select_listDelegate(ushort n, ushort list_2);
        public delegate void select_listDelegate(ushort list_2);
        public delegate void n_set_extstartposDelegate(ushort n, int position);
        public delegate void set_extstartposDelegate(int position);
        public delegate void n_z_outDelegate(ushort n, short z);
        public delegate void z_outDelegate(short z);
        public delegate void n_set_firstpulse_killerDelegate(ushort n, ushort fpk);
        public delegate void set_firstpulse_killerDelegate(ushort fpk);
        public delegate void n_set_standbyDelegate(ushort n, ushort half_period, ushort pulse);
        public delegate void set_standbyDelegate(ushort half_period, ushort pulse);
        public delegate void n_laser_signal_onDelegate(ushort n);
        public delegate void laser_signal_onDelegate();
        public delegate void n_laser_signal_offDelegate(ushort n);
        public delegate void laser_signal_offDelegate();
        public delegate void n_set_delay_modeDelegate(ushort n, ushort varpoly, ushort directmove3d, ushort edgelevel, ushort minjumpdelay, ushort jumplengthlimit);
        public delegate void set_delay_modeDelegate(ushort varpoly, ushort directmove3d, ushort edgelevel, ushort minjumpdelay, ushort jumplengthlimit);
        public delegate void n_set_piso_controlDelegate(ushort n, ushort l1, ushort l2);
        public delegate void set_piso_controlDelegate(ushort l1, ushort l2);
        public delegate void n_select_statusDelegate(ushort n, ushort mode);
        public delegate void select_statusDelegate(ushort mode);
        public delegate void n_get_encoderDelegate(ushort n, out short zx, out short zy);
        public delegate void get_encoderDelegate(out short zx, out short zy);
        public delegate void n_select_cor_tableDelegate(ushort n, ushort heada, ushort headb);
        public delegate void select_cor_tableDelegate(ushort heada, ushort headb);
        public delegate void n_execute_at_pointerDelegate(ushort n, int position);
        public delegate void execute_at_pointerDelegate(int position);
        public delegate ushort n_get_head_statusDelegate(ushort n, ushort head);
        public delegate ushort get_head_statusDelegate(ushort head);
        public delegate void n_simulate_encoderDelegate(ushort n, ushort channel);
        public delegate void simulate_encoderDelegate(ushort channel);
        public delegate void n_release_waitDelegate(ushort n);
        public delegate void release_waitDelegate();
        public delegate ushort n_get_wait_statusDelegate(ushort n);
        public delegate ushort get_wait_statusDelegate();
        public delegate void n_set_control_modeDelegate(ushort n, ushort mode);
        public delegate void set_control_modeDelegate(ushort mode);
        public delegate void n_set_laser_modeDelegate(ushort n, ushort mode);
        public delegate void set_laser_modeDelegate(ushort mode);
        public delegate void n_set_ext_start_delayDelegate(ushort n, short delay, short encoder);
        public delegate void set_ext_start_delayDelegate(short delay, short encoder);
        public delegate void n_home_positionDelegate(ushort n, short xhome, short yhome);
        public delegate void home_positionDelegate(short xhome, short yhome);
        public delegate ushort n_read_ad_xDelegate(ushort n, ushort x);
        public delegate ushort read_ad_xDelegate(ushort x);
        public delegate short n_get_z_distanceDelegate(ushort n, short x, short y, short z);
        public delegate short get_z_distanceDelegate(short x, short y, short z);
        public delegate ushort n_get_startstop_infoDelegate(ushort n);
        public delegate ushort get_startstop_infoDelegate();
        public delegate ushort n_get_marking_infoDelegate(ushort n);
        public delegate ushort get_marking_infoDelegate();
        public delegate ushort n_get_io_statusDelegate(ushort n);
        public delegate ushort get_io_statusDelegate();
        public delegate double n_get_timeDelegate(ushort n);
        public delegate double get_timeDelegate();
        public delegate void n_set_defocusDelegate(ushort n, short value);
        public delegate void set_defocusDelegate(short value);
        public delegate void n_set_softstart_modeDelegate(ushort n, ushort mode, ushort number, ushort restartdelay);
        public delegate void set_softstart_modeDelegate(ushort mode, ushort number, ushort restartdelay);
        public delegate void n_set_softstart_levelDelegate(ushort n, ushort index, ushort level);
        public delegate void set_softstart_levelDelegate(ushort index, ushort level);
        public delegate void n_control_commandDelegate(ushort n, ushort head, ushort axis, ushort data);
        public delegate void control_commandDelegate(ushort head, ushort axis, ushort data);
        public delegate void n_set_rot_centerDelegate(ushort n, int center_x, int center_y);
        public delegate void set_rot_centerDelegate(int center_x, int center_y);
        public delegate void n_auto_change_posDelegate(ushort n, int start);
        public delegate void auto_change_posDelegate(int start);
        public delegate short n_get_valueDelegate(ushort n, ushort signal);
        public delegate short get_valueDelegate(ushort signal);
        public delegate void n_set_io_bitDelegate(ushort n, ushort mask1);
        public delegate void set_io_bitDelegate(ushort mask1);
        public delegate void n_clear_io_bitDelegate(ushort n, ushort mask0);
        public delegate void clear_io_bitDelegate(ushort mask0);
        public delegate void n_set_duty_cycle_tableDelegate(ushort n, ushort index, ushort dutycycle);
        public delegate void set_duty_cycle_tableDelegate(ushort index, ushort dutycycle);
        public delegate void n_set_laser_timing_tableDelegate(ushort n, ushort index, double f);
        public delegate void set_laser_timing_tableDelegate(ushort index, double f);
        public delegate short n_store_on_mmcDelegate(ushort n);
        public delegate short store_on_mmcDelegate();
        public delegate ushort n_get_serial_numberDelegate(ushort n);
        public delegate ushort get_serial_numberDelegate();
        public delegate int n_get_serial_number_32Delegate(ushort n);
        public delegate int get_serial_number_32Delegate();
        public delegate void n_measurement_statusDelegate(ushort n, out ushort busy, out ushort position);
        public delegate void measurement_statusDelegate(out ushort busy, out ushort position);
        public delegate void n_clear_listDelegate(ushort n);
        public delegate void clear_listDelegate();
        public delegate void n_set_char_tableDelegate(ushort n, ushort ch, int listpos);
        public delegate void set_char_tableDelegate(ushort ch, int listpos);
        public delegate void n_time_updateDelegate(ushort n);
        public delegate void time_updateDelegate();
        public delegate void n_set_serialDelegate(ushort n, int no);
        public delegate void set_serialDelegate(int no);
        public delegate int n_memory_testDelegate(ushort n);
        public delegate int memory_testDelegate();
        public delegate void n_list_nopDelegate(ushort n);
        public delegate void list_nopDelegate();
        public delegate void n_set_end_of_listDelegate(ushort n);
        public delegate void set_end_of_listDelegate();
        public delegate void n_jump_absDelegate(ushort n, short x, short y);
        public delegate void jump_absDelegate(short x, short y);
        public delegate void n_jump_abs_3dDelegate(ushort n, short x, short y, short z);
        public delegate void jump_abs_3dDelegate(short x, short y, short z);
        public delegate void n_mark_absDelegate(ushort n, short x, short y);
        public delegate void mark_absDelegate(short x, short y);
        public delegate void n_mark_abs_3dDelegate(ushort n, short x, short y, short z);
        public delegate void mark_abs_3dDelegate(short x, short y, short z);
        public delegate void n_jump_relDelegate(ushort n, short dx, short dy);
        public delegate void jump_relDelegate(short dx, short dy);
        public delegate void n_jump_rel_3dDelegate(ushort n, short dx, short dy, short dz);
        public delegate void jump_rel_3dDelegate(short dx, short dy, short dz);
        public delegate void n_mark_relDelegate(ushort n, short dx, short dy);
        public delegate void mark_relDelegate(short dx, short dy);
        public delegate void n_mark_rel_3dDelegate(ushort n, short dx, short dy, short dz);
        public delegate void mark_rel_3dDelegate(short dx, short dy, short dz);
        public delegate void n_write_8bit_port_listDelegate(ushort n, ushort value);
        public delegate void write_8bit_port_listDelegate(ushort value);
        public delegate void n_write_da_1_listDelegate(ushort n, ushort value);
        public delegate void write_da_1_listDelegate(ushort value);
        public delegate void n_write_da_2_listDelegate(ushort n, ushort value);
        public delegate void write_da_2_listDelegate(ushort value);
        public delegate void n_write_da_x_listDelegate(ushort n, ushort x, ushort value);
        public delegate void write_da_x_listDelegate(ushort x, ushort value);
        public delegate void n_set_offset_listDelegate(ushort n, short xoffset, short yoffset);
        public delegate void set_offset_listDelegate(short xoffset, short yoffset);
        public delegate void n_long_delayDelegate(ushort n, ushort value);
        public delegate void long_delayDelegate(ushort value);
        public delegate void n_laser_on_listDelegate(ushort n, ushort value);
        public delegate void laser_on_listDelegate(ushort value);
        public delegate void n_set_jump_speedDelegate(ushort n, double speed);
        public delegate void set_jump_speedDelegate(double speed);
        public delegate void n_set_mark_speedDelegate(ushort n, double speed);
        public delegate void set_mark_speedDelegate(double speed);
        public delegate void n_set_laser_delaysDelegate(ushort n, short ondelay, short offdelay);
        public delegate void set_laser_delaysDelegate(short ondelay, short offdelay);
        public delegate void n_set_scanner_delaysDelegate(ushort n, ushort jumpdelay, ushort markdelay, ushort polydelay);
        public delegate void set_scanner_delaysDelegate(ushort jumpdelay, ushort markdelay, ushort polydelay);
        public delegate void n_set_list_jumpDelegate(ushort n, int position);
        public delegate void set_list_jumpDelegate(int position);
        public delegate void n_list_callDelegate(ushort n, int position);
        public delegate void list_callDelegate(int position);
        public delegate void n_list_returnDelegate(ushort n);
        public delegate void list_returnDelegate();
        public delegate void n_z_out_listDelegate(ushort n, short z);
        public delegate void z_out_listDelegate(short z);
        public delegate void n_set_standby_listDelegate(ushort n, ushort half_period, ushort pulse);
        public delegate void set_standby_listDelegate(ushort half_period, ushort pulse);
        public delegate void n_timed_jump_absDelegate(ushort n, short x, short y, double time);
        public delegate void timed_jump_absDelegate(short x, short y, double time);
        public delegate void n_timed_mark_absDelegate(ushort n, short x, short y, double time);
        public delegate void timed_mark_absDelegate(short x, short y, double time);
        public delegate void n_timed_jump_relDelegate(ushort n, short dx, short dy, double time);
        public delegate void timed_jump_relDelegate(short dx, short dy, double time);
        public delegate void n_timed_mark_relDelegate(ushort n, short dx, short dy, double time);
        public delegate void timed_mark_relDelegate(short dx, short dy, double time);
        public delegate void n_set_laser_timingDelegate(ushort n, ushort halfperiod, ushort pulse1, ushort pulse2, ushort timebase);
        public delegate void set_laser_timingDelegate(ushort halfperiod, ushort pulse1, ushort pulse2, ushort timebase);
        public delegate void n_set_wobbelDelegate(ushort n, ushort amplitude, double frequency);
        public delegate void set_wobbelDelegate(ushort amplitude, double frequency);
        public delegate void n_set_fly_xDelegate(ushort n, double kx);
        public delegate void set_fly_xDelegate(double kx);
        public delegate void n_set_fly_yDelegate(ushort n, double ky);
        public delegate void set_fly_yDelegate(double ky);
        public delegate void n_write_io_port_listDelegate(ushort n, ushort value);
        public delegate void write_io_port_listDelegate(ushort value);
        public delegate void n_set_waitDelegate(ushort n, ushort value);
        public delegate void set_waitDelegate(ushort value);
        public delegate void n_simulate_ext_startDelegate(ushort n, short delay, short encoder);
        public delegate void simulate_ext_startDelegate(short delay, short encoder);
        public delegate void n_set_pixel_lineDelegate(ushort n, ushort pixelmode, ushort pixelperiod, double dx, double dy);
        public delegate void set_pixel_lineDelegate(ushort pixelmode, ushort pixelperiod, double dx, double dy);
        public delegate void n_set_pixelDelegate(ushort n, ushort pulswidth, ushort davalue, ushort dummy);
        public delegate void set_pixelDelegate(ushort pulswidth, ushort davalue, ushort dummy);
        public delegate void n_set_extstartpos_listDelegate(ushort n, int position);
        public delegate void set_extstartpos_listDelegate(int position);
        public delegate void n_laser_signal_on_listDelegate(ushort n);
        public delegate void laser_signal_on_listDelegate();
        public delegate void n_laser_signal_off_listDelegate(ushort n);
        public delegate void laser_signal_off_listDelegate();
        public delegate void n_set_firstpulse_killer_listDelegate(ushort n, ushort fpk);
        public delegate void set_firstpulse_killer_listDelegate(ushort fpk);
        public delegate void n_set_io_cond_listDelegate(ushort n, ushort mask_1, ushort mask_0, ushort mask_set);
        public delegate void set_io_cond_listDelegate(ushort mask_1, ushort mask_0, ushort mask_set);
        public delegate void n_clear_io_cond_listDelegate(ushort n, ushort mask_1, ushort mask_0, ushort mask_clear);
        public delegate void clear_io_cond_listDelegate(ushort mask_1, ushort mask_0, ushort mask_clear);
        public delegate void n_list_jump_condDelegate(ushort n, ushort mask_1, ushort mask_0, int position);
        public delegate void list_jump_condDelegate(ushort mask_1, ushort mask_0, int position);
        public delegate void n_list_call_condDelegate(ushort n, ushort mask_1, ushort mask_0, int position);
        public delegate void list_call_condDelegate(ushort mask_1, ushort mask_0, int position);
        public delegate void n_save_and_restart_timerDelegate(ushort n);
        public delegate void save_and_restart_timerDelegate();
        public delegate void n_set_matrix_listDelegate(ushort n, ushort i, ushort j, double mij);
        public delegate void set_matrix_listDelegate(ushort i, ushort j, double mij);
        public delegate void n_set_control_mode_listDelegate(ushort n, ushort mode);
        public delegate void set_control_mode_listDelegate(ushort mode);
        public delegate void n_set_defocus_listDelegate(ushort n, short value);
        public delegate void set_defocus_listDelegate(short value);
        public delegate void n_set_ext_start_delay_listDelegate(ushort n, short delay, short encoder);
        public delegate void set_ext_start_delay_listDelegate(short delay, short encoder);
        public delegate void n_set_wobbel_xyDelegate(ushort n, ushort long_wob, ushort trans_wob, double frequency);
        public delegate void set_wobbel_xyDelegate(ushort long_wob, ushort trans_wob, double frequency);
        public delegate void n_calculate_flyDelegate(ushort n, ushort direction, double distance);
        public delegate void calculate_flyDelegate(ushort direction, double distance);
        public delegate void n_select_cor_table_listDelegate(ushort n, ushort heada, ushort headb);
        public delegate void select_cor_table_listDelegate(ushort heada, ushort headb);
        public delegate void n_set_fly_rotDelegate(ushort n, double resolution);
        public delegate void set_fly_rotDelegate(double resolution);
        public delegate void n_fly_returnDelegate(ushort n, short x, short y);
        public delegate void fly_returnDelegate(short x, short y);
        public delegate void n_set_triggerDelegate(ushort n, ushort sampleperiod, ushort channel1, ushort channel2);
        public delegate void set_triggerDelegate(ushort sampleperiod, ushort channel1, ushort channel2);
        public delegate void n_arc_relDelegate(ushort n, short dx, short dy, double angle);
        public delegate void arc_relDelegate(short dx, short dy, double angle);
        public delegate void n_arc_absDelegate(ushort n, short x, short y, double angle);
        public delegate void arc_absDelegate(short x, short y, double angle);
        public delegate void n_time_fixDelegate(ushort n);
        public delegate void time_fixDelegate();
        public delegate void n_time_fix_fDelegate(ushort n, ushort mode);
        public delegate void time_fix_fDelegate(ushort mode);
        public delegate void n_mark_timeDelegate(ushort n, ushort part, ushort mode);
        public delegate void mark_timeDelegate(ushort part, ushort mode);
        public delegate void n_mark_dateDelegate(ushort n, ushort part, ushort mode);
        public delegate void mark_dateDelegate(ushort part, ushort mode);
        public delegate void n_mark_serialDelegate(ushort n, ushort mode, ushort digits);
        public delegate void mark_serialDelegate(ushort mode, ushort digits);
        public delegate void n_date_checkDelegate(ushort n, ushort month1, ushort month2, ushort month3);
        public delegate void date_checkDelegate(ushort month1, ushort month2, ushort month3);
        public delegate void n_flylineDelegate(ushort n, short encoderdelay);
        public delegate void flylineDelegate(short encoderdelay);
        public delegate void n_drillingDelegate(ushort n, short pulsewidth, short relencoderdelay);
        public delegate void drillingDelegate(short pulsewidth, short relencoderdelay);
        public delegate void n_regulationDelegate(ushort n);
        public delegate void regulationDelegate();
        public delegate void n_regulation2Delegate(ushort n, double fmax, double fmin);
        public delegate void regulation2Delegate(double fmax, double fmin);
        public delegate void n_regulation3Delegate(ushort n, double fmax, double fmin);
        public delegate void regulation3Delegate(double fmax, double fmin);
        public delegate void n_store_encoderDelegate(ushort n);
        public delegate void store_encoderDelegate();
        public delegate void n_fly_displacement_retDelegate(ushort n, short x, short y);
        public delegate void fly_displacement_retDelegate(short x, short y);
        public delegate int usb_reinitializeDelegate(out int foundcards);
        #endregion

        #region SCANalone4UserFunctions
        /// <summary>
        ///  ushort scanalone_count_cards();
        /// </summary>
        public static scanalone_count_cardsDelegate scanalone_count_cards;

        /// <summary>
        ///  select_rtc(ushort n);
        /// </summary>
        public static select_rtcDelegate select_rtc;

        /// <summary>
        ///  int n_usb_status(ushort n);
        /// </summary>
        public static n_usb_statusDelegate n_usb_status;

        /// <summary>
        ///  int usb_status();
        /// </summary>
        public static usb_statusDelegate usb_status;

        /// <summary>
        ///  short n_load_correction_file(ushort n, string filename, short cortable, double kx, double ky, double phi, double xoffset, double yoffset);
        /// </summary>
        public static n_load_correction_fileDelegate n_load_correction_file;

        /// <summary>
        ///  short load_correction_file(string filename, short cortable, double kx, double ky, double phi, double xoffset, double yoffset);
        /// </summary>
        public static load_correction_fileDelegate load_correction_file;

        /// <summary>
        ///  short n_load_cor(ushort n, string filename);
        /// </summary>
        public static n_load_corDelegate n_load_cor;

        /// <summary>
        ///  short load_cor(string filename);
        /// </summary>
        public static load_corDelegate load_cor;

        /// <summary>
        ///  n_stop_execution(ushort n);
        /// </summary>
        public static n_stop_executionDelegate n_stop_execution;

        /// <summary>
        ///  short n_load_program_file(ushort n, string name);
        /// </summary>
        public static n_load_program_fileDelegate n_load_program_file;

        /// <summary>
        ///  short load_program_file(string name);
        /// </summary>
        public static load_program_fileDelegate load_program_file;

        /// <summary>
        ///  short n_load_pro(ushort n, string filename);
        /// </summary>
        public static n_load_proDelegate n_load_pro;

        /// <summary>
        ///  short load_pro(string filename);
        /// </summary>
        public static load_proDelegate load_pro;

        /// <summary>
        ///  short n_load_varpolydelay(ushort n, string stbfilename, ushort tableno);
        /// </summary>
        public static n_load_varpolydelayDelegate n_load_varpolydelay;

        /// <summary>
        ///  short load_varpolydelay(string stbfilename, ushort tableno);
        /// </summary>
        public static load_varpolydelayDelegate load_varpolydelay;

        /// <summary>
        ///  short n_load_z_table(ushort n, double a, double b, double c);
        /// </summary>
        public static n_load_z_tableDelegate n_load_z_table;

        /// <summary>
        ///  short load_z_table(double a, double b, double c);
        /// </summary>
        public static load_z_tableDelegate load_z_table;

        /// <summary>
        ///  n_get_waveform(ushort n, ushort channel, ushort stopp, short[] memptr);
        /// </summary>
        public static n_get_waveformDelegate n_get_waveform;

        /// <summary>
        ///  get_waveform(ushort channel, ushort stopp, short[] memptr);
        /// </summary>
        public static get_waveformDelegate get_waveform;

        /// <summary>
        ///  n_get_status(ushort n, out ushort busy, out int position);
        /// </summary>
        public static n_get_statusDelegate n_get_status;

        /// <summary>
        ///  get_status(out ushort busy, out int position);
        /// </summary>
        public static get_statusDelegate get_status;

        /// <summary>
        ///  ushort n_read_status(ushort n);
        /// </summary>
        public static n_read_statusDelegate n_read_status;

        /// <summary>
        ///  ushort read_status();
        /// </summary>
        public static read_statusDelegate read_status;

        /// <summary>
        ///  ushort get_dll_version();
        /// </summary>
        public static get_dll_versionDelegate get_dll_version;

        /// <summary>
        ///  int n_get_input_pointer(ushort n);
        /// </summary>
        public static n_get_input_pointerDelegate n_get_input_pointer;

        /// <summary>
        ///  int get_input_pointer();
        /// </summary>
        public static get_input_pointerDelegate get_input_pointer;

        /// <summary>
        ///  n_set_input_pointer(ushort n, int pointer);
        /// </summary>
        public static n_set_input_pointerDelegate n_set_input_pointer;

        /// <summary>
        ///  set_input_pointer(int pointer);
        /// </summary>
        public static set_input_pointerDelegate set_input_pointer;

        /// <summary>
        ///  n_set_start_list_1(ushort n);
        /// </summary>
        public static n_set_start_list_1Delegate n_set_start_list_1;

        /// <summary>
        ///  set_start_list_1();
        /// </summary>
        public static set_start_list_1Delegate set_start_list_1;

        /// <summary>
        ///  n_set_start_list_2(ushort n);
        /// </summary>
        public static n_set_start_list_2Delegate n_set_start_list_2;

        /// <summary>
        ///  set_start_list_2();
        /// </summary>
        public static set_start_list_2Delegate set_start_list_2;

        /// <summary>
        ///  n_set_start_list(ushort n, ushort listno);
        /// </summary>
        public static n_set_start_listDelegate n_set_start_list;

        /// <summary>
        ///  set_start_list(ushort listno);
        /// </summary>
        public static set_start_listDelegate set_start_list;

        /// <summary>
        ///  n_execute_list_1(ushort n);
        /// </summary>
        public static n_execute_list_1Delegate n_execute_list_1;

        /// <summary>
        ///  execute_list_1();
        /// </summary>
        public static execute_list_1Delegate execute_list_1;

        /// <summary>
        ///  n_execute_list_2(ushort n);
        /// </summary>
        public static n_execute_list_2Delegate n_execute_list_2;

        /// <summary>
        ///  execute_list_2();
        /// </summary>
        public static execute_list_2Delegate execute_list_2;

        /// <summary>
        ///  n_execute_list(ushort n, ushort listno);
        /// </summary>
        public static n_execute_listDelegate n_execute_list;

        /// <summary>
        ///  execute_list(ushort listno);
        /// </summary>
        public static execute_listDelegate execute_list;

        /// <summary>
        ///  n_write_8bit_port(ushort n, ushort value);
        /// </summary>
        public static n_write_8bit_portDelegate n_write_8bit_port;

        /// <summary>
        ///  write_8bit_port(ushort value);
        /// </summary>
        public static write_8bit_portDelegate write_8bit_port;

        /// <summary>
        ///  n_write_io_port(ushort n, ushort value);
        /// </summary>
        public static n_write_io_portDelegate n_write_io_port;

        /// <summary>
        ///  write_io_port(ushort value);
        /// </summary>
        public static write_io_portDelegate write_io_port;

        /// <summary>
        ///  n_auto_change(ushort n);
        /// </summary>
        public static n_auto_changeDelegate n_auto_change;

        /// <summary>
        ///  auto_change();
        /// </summary>
        public static auto_changeDelegate auto_change;

        /// <summary>
        ///  n_aut_change(ushort n);
        /// </summary>
        public static n_aut_changeDelegate n_aut_change;

        /// <summary>
        ///  aut_change();
        /// </summary>
        public static aut_changeDelegate aut_change;

        /// <summary>
        ///  n_start_loop(ushort n);
        /// </summary>
        public static n_start_loopDelegate n_start_loop;

        /// <summary>
        ///  start_loop();
        /// </summary>
        public static start_loopDelegate start_loop;

        /// <summary>
        ///  n_quit_loop(ushort n);
        /// </summary>
        public static n_quit_loopDelegate n_quit_loop;

        /// <summary>
        ///  quit_loop();
        /// </summary>
        public static quit_loopDelegate quit_loop;

        /// <summary>
        ///  stop_execution();
        /// </summary>
        public static stop_executionDelegate stop_execution;

        /// <summary>
        ///  n_dsp_start(ushort n);
        /// </summary>
        public static n_dsp_startDelegate n_dsp_start;

        /// <summary>
        ///  dsp_start();
        /// </summary>
        public static dsp_startDelegate dsp_start;

        /// <summary>
        ///  ushort n_read_io_port(ushort n);
        /// </summary>
        public static n_read_io_portDelegate n_read_io_port;

        /// <summary>
        ///  ushort read_io_port();
        /// </summary>
        public static read_io_portDelegate read_io_port;

        /// <summary>
        ///  n_write_da_1(ushort n, ushort value);
        /// </summary>
        public static n_write_da_1Delegate n_write_da_1;

        /// <summary>
        ///  write_da_1(ushort value);
        /// </summary>
        public static write_da_1Delegate write_da_1;

        /// <summary>
        ///  n_write_da_2(ushort n, ushort value);
        /// </summary>
        public static n_write_da_2Delegate n_write_da_2;

        /// <summary>
        ///  write_da_2(ushort value);
        /// </summary>
        public static write_da_2Delegate write_da_2;

        /// <summary>
        ///  n_write_da_x(ushort n, ushort x, ushort value);
        /// </summary>
        public static n_write_da_xDelegate n_write_da_x;

        /// <summary>
        ///  write_da_x(ushort x, ushort value);
        /// </summary>
        public static write_da_xDelegate write_da_x;

        /// <summary>
        ///  n_set_max_counts(ushort n, int counts);
        /// </summary>
        public static n_set_max_countsDelegate n_set_max_counts;

        /// <summary>
        ///  set_max_counts(int counts);
        /// </summary>
        public static set_max_countsDelegate set_max_counts;

        /// <summary>
        ///  int n_get_counts(ushort n);
        /// </summary>
        public static n_get_countsDelegate n_get_counts;

        /// <summary>
        ///  int get_counts();
        /// </summary>
        public static get_countsDelegate get_counts;

        /// <summary>
        ///  n_set_matrix(ushort n, double m11, double m12, double m21, double m22);
        /// </summary>
        public static n_set_matrixDelegate n_set_matrix;

        /// <summary>
        ///  set_matrix(double m11, double m12, double m21, double m22);
        /// </summary>
        public static set_matrixDelegate set_matrix;

        /// <summary>
        ///  n_set_offset(ushort n, short xoffset, short yoffset);
        /// </summary>
        public static n_set_offsetDelegate n_set_offset;

        /// <summary>
        ///  set_offset(short xoffset, short yoffset);
        /// </summary>
        public static set_offsetDelegate set_offset;

        /// <summary>
        ///  n_goto_xy(ushort n, short x, short y);
        /// </summary>
        public static n_goto_xyDelegate n_goto_xy;

        /// <summary>
        ///  goto_xy(short x, short y);
        /// </summary>
        public static goto_xyDelegate goto_xy;

        /// <summary>
        ///  n_goto_xyz(ushort n, short x, short y, short z);
        /// </summary>
        public static n_goto_xyzDelegate n_goto_xyz;

        /// <summary>
        ///  goto_xyz(short x, short y, short z);
        /// </summary>
        public static goto_xyzDelegate goto_xyz;

        /// <summary>
        ///  ushort n_get_hex_version(ushort n);
        /// </summary>
        public static n_get_hex_versionDelegate n_get_hex_version;

        /// <summary>
        ///  ushort get_hex_version();
        /// </summary>
        public static get_hex_versionDelegate get_hex_version;

        /// <summary>
        ///  n_enable_laser(ushort n);
        /// </summary>
        public static n_enable_laserDelegate n_enable_laser;

        /// <summary>
        ///  enable_laser();
        /// </summary>
        public static enable_laserDelegate enable_laser;

        /// <summary>
        ///  n_disable_laser(ushort n);
        /// </summary>
        public static n_disable_laserDelegate n_disable_laser;

        /// <summary>
        ///  disable_laser();
        /// </summary>
        public static disable_laserDelegate disable_laser;

        /// <summary>
        ///  n_stop_list(ushort n);
        /// </summary>
        public static n_stop_listDelegate n_stop_list;

        /// <summary>
        ///  stop_list();
        /// </summary>
        public static stop_listDelegate stop_list;

        /// <summary>
        ///  n_restart_list(ushort n);
        /// </summary>
        public static n_restart_listDelegate n_restart_list;

        /// <summary>
        ///  restart_list();
        /// </summary>
        public static restart_listDelegate restart_list;

        /// <summary>
        ///  ushort n_get_rtc_version(ushort n);
        /// </summary>
        public static n_get_rtc_versionDelegate n_get_rtc_version;

        /// <summary>
        ///  ushort get_rtc_version();
        /// </summary>
        public static get_rtc_versionDelegate get_rtc_version;

        /// <summary>
        ///  n_get_xy_pos(ushort n, out short x, out short y);
        /// </summary>
        public static n_get_xy_posDelegate n_get_xy_pos;

        /// <summary>
        ///  get_xy_pos(out short x, out short y);
        /// </summary>
        public static get_xy_posDelegate get_xy_pos;

        /// <summary>
        ///  n_get_xyz_pos(ushort n, out short x, out short y, out short z);
        /// </summary>
        public static n_get_xyz_posDelegate n_get_xyz_pos;

        /// <summary>
        ///  get_xyz_pos(out short x, out short y, out short z);
        /// </summary>
        public static get_xyz_posDelegate get_xyz_pos;

        /// <summary>
        ///  n_select_list(ushort n, ushort list_2);
        /// </summary>
        public static n_select_listDelegate n_select_list;

        /// <summary>
        ///  select_list(ushort list_2);
        /// </summary>
        public static select_listDelegate select_list;

        /// <summary>
        ///  n_set_extstartpos(ushort n, int position);
        /// </summary>
        public static n_set_extstartposDelegate n_set_extstartpos;

        /// <summary>
        ///  set_extstartpos(int position);
        /// </summary>
        public static set_extstartposDelegate set_extstartpos;

        /// <summary>
        ///  n_z_out(ushort n, short z);
        /// </summary>
        public static n_z_outDelegate n_z_out;

        /// <summary>
        ///  z_out(short z);
        /// </summary>
        public static z_outDelegate z_out;

        /// <summary>
        ///  n_set_firstpulse_killer(ushort n, ushort fpk);
        /// </summary>
        public static n_set_firstpulse_killerDelegate n_set_firstpulse_killer;

        /// <summary>
        ///  set_firstpulse_killer(ushort fpk);
        /// </summary>
        public static set_firstpulse_killerDelegate set_firstpulse_killer;

        /// <summary>
        ///  n_set_standby(ushort n, ushort half_period, ushort pulse);
        /// </summary>
        public static n_set_standbyDelegate n_set_standby;

        /// <summary>
        ///  set_standby(ushort half_period, ushort pulse);
        /// </summary>
        public static set_standbyDelegate set_standby;

        /// <summary>
        ///  n_laser_signal_on(ushort n);
        /// </summary>
        public static n_laser_signal_onDelegate n_laser_signal_on;

        /// <summary>
        ///  laser_signal_on();
        /// </summary>
        public static laser_signal_onDelegate laser_signal_on;

        /// <summary>
        ///  n_laser_signal_off(ushort n);
        /// </summary>
        public static n_laser_signal_offDelegate n_laser_signal_off;

        /// <summary>
        ///  laser_signal_off();
        /// </summary>
        public static laser_signal_offDelegate laser_signal_off;

        /// <summary>
        ///  n_set_delay_mode(ushort n, ushort varpoly, ushort directmove3d, ushort edgelevel, ushort minjumpdelay, ushort jumplengthlimit);
        /// </summary>
        public static n_set_delay_modeDelegate n_set_delay_mode;

        /// <summary>
        ///  set_delay_mode(ushort varpoly, ushort directmove3d, ushort edgelevel, ushort minjumpdelay, ushort jumplengthlimit);
        /// </summary>
        public static set_delay_modeDelegate set_delay_mode;

        /// <summary>
        ///  n_set_piso_control(ushort n, ushort l1, ushort l2);
        /// </summary>
        public static n_set_piso_controlDelegate n_set_piso_control;

        /// <summary>
        ///  set_piso_control(ushort l1, ushort l2);
        /// </summary>
        public static set_piso_controlDelegate set_piso_control;

        /// <summary>
        ///  n_select_status(ushort n, ushort mode);
        /// </summary>
        public static n_select_statusDelegate n_select_status;

        /// <summary>
        ///  select_status(ushort mode);
        /// </summary>
        public static select_statusDelegate select_status;

        /// <summary>
        ///  n_get_encoder(ushort n, out short zx, out short zy);
        /// </summary>
        public static n_get_encoderDelegate n_get_encoder;

        /// <summary>
        ///  get_encoder(out short zx, out short zy);
        /// </summary>
        public static get_encoderDelegate get_encoder;

        /// <summary>
        ///  n_select_cor_table(ushort n, ushort heada, ushort headb);
        /// </summary>
        public static n_select_cor_tableDelegate n_select_cor_table;

        /// <summary>
        ///  select_cor_table(ushort heada, ushort headb);
        /// </summary>
        public static select_cor_tableDelegate select_cor_table;

        /// <summary>
        ///  n_execute_at_pointer(ushort n, int position);
        /// </summary>
        public static n_execute_at_pointerDelegate n_execute_at_pointer;

        /// <summary>
        ///  execute_at_pointer(int position);
        /// </summary>
        public static execute_at_pointerDelegate execute_at_pointer;

        /// <summary>
        ///  ushort n_get_head_status(ushort n, ushort head);
        /// </summary>
        public static n_get_head_statusDelegate n_get_head_status;

        /// <summary>
        ///  ushort get_head_status(ushort head);
        /// </summary>
        public static get_head_statusDelegate get_head_status;

        /// <summary>
        ///  n_simulate_encoder(ushort n, ushort channel);
        /// </summary>
        public static n_simulate_encoderDelegate n_simulate_encoder;

        /// <summary>
        ///  simulate_encoder(ushort channel);
        /// </summary>
        public static simulate_encoderDelegate simulate_encoder;

        /// <summary>
        ///  n_release_wait(ushort n);
        /// </summary>
        public static n_release_waitDelegate n_release_wait;

        /// <summary>
        ///  release_wait();
        /// </summary>
        public static release_waitDelegate release_wait;

        /// <summary>
        ///  ushort n_get_wait_status(ushort n);
        /// </summary>
        public static n_get_wait_statusDelegate n_get_wait_status;

        /// <summary>
        ///  ushort get_wait_status();
        /// </summary>
        public static get_wait_statusDelegate get_wait_status;

        /// <summary>
        ///  n_set_control_mode(ushort n, ushort mode);
        /// </summary>
        public static n_set_control_modeDelegate n_set_control_mode;

        /// <summary>
        ///  set_control_mode(ushort mode);
        /// </summary>
        public static set_control_modeDelegate set_control_mode;

        /// <summary>
        ///  n_set_laser_mode(ushort n, ushort mode);
        /// </summary>
        public static n_set_laser_modeDelegate n_set_laser_mode;

        /// <summary>
        ///  set_laser_mode(ushort mode);
        /// </summary>
        public static set_laser_modeDelegate set_laser_mode;

        /// <summary>
        ///  n_set_ext_start_delay(ushort n, short delay, short encoder);
        /// </summary>
        public static n_set_ext_start_delayDelegate n_set_ext_start_delay;

        /// <summary>
        ///  set_ext_start_delay(short delay, short encoder);
        /// </summary>
        public static set_ext_start_delayDelegate set_ext_start_delay;

        /// <summary>
        ///  n_home_position(ushort n, short xhome, short yhome);
        /// </summary>
        public static n_home_positionDelegate n_home_position;

        /// <summary>
        ///  home_position(short xhome, short yhome);
        /// </summary>
        public static home_positionDelegate home_position;

        /// <summary>
        ///  ushort n_read_ad_x(ushort n, ushort x);
        /// </summary>
        public static n_read_ad_xDelegate n_read_ad_x;

        /// <summary>
        ///  ushort read_ad_x(ushort x);
        /// </summary>
        public static read_ad_xDelegate read_ad_x;

        /// <summary>
        ///  short n_get_z_distance(ushort n, short x, short y, short z);
        /// </summary>
        public static n_get_z_distanceDelegate n_get_z_distance;

        /// <summary>
        ///  short get_z_distance(short x, short y, short z);
        /// </summary>
        public static get_z_distanceDelegate get_z_distance;

        /// <summary>
        ///  ushort n_get_startstop_info(ushort n);
        /// </summary>
        public static n_get_startstop_infoDelegate n_get_startstop_info;

        /// <summary>
        ///  ushort get_startstop_info();
        /// </summary>
        public static get_startstop_infoDelegate get_startstop_info;

        /// <summary>
        ///  ushort n_get_marking_info(ushort n);
        /// </summary>
        public static n_get_marking_infoDelegate n_get_marking_info;

        /// <summary>
        ///  ushort get_marking_info();
        /// </summary>
        public static get_marking_infoDelegate get_marking_info;

        /// <summary>
        ///  ushort n_get_io_status(ushort n);
        /// </summary>
        public static n_get_io_statusDelegate n_get_io_status;

        /// <summary>
        ///  ushort get_io_status();
        /// </summary>
        public static get_io_statusDelegate get_io_status;

        /// <summary>
        ///  double n_get_time(ushort n);
        /// </summary>
        public static n_get_timeDelegate n_get_time;

        /// <summary>
        ///  double get_time();
        /// </summary>
        public static get_timeDelegate get_time;

        /// <summary>
        ///  n_set_defocus(ushort n, short value);
        /// </summary>
        public static n_set_defocusDelegate n_set_defocus;

        /// <summary>
        ///  set_defocus(short value);
        /// </summary>
        public static set_defocusDelegate set_defocus;

        /// <summary>
        ///  n_set_softstart_mode(ushort n, ushort mode, ushort number, ushort restartdelay);
        /// </summary>
        public static n_set_softstart_modeDelegate n_set_softstart_mode;

        /// <summary>
        ///  set_softstart_mode(ushort mode, ushort number, ushort restartdelay);
        /// </summary>
        public static set_softstart_modeDelegate set_softstart_mode;

        /// <summary>
        ///  n_set_softstart_level(ushort n, ushort index, ushort level);
        /// </summary>
        public static n_set_softstart_levelDelegate n_set_softstart_level;

        /// <summary>
        ///  set_softstart_level(ushort index, ushort level);
        /// </summary>
        public static set_softstart_levelDelegate set_softstart_level;

        /// <summary>
        ///  n_control_command(ushort n, ushort head, ushort axis, ushort data);
        /// </summary>
        public static n_control_commandDelegate n_control_command;

        /// <summary>
        ///  control_command(ushort head, ushort axis, ushort data);
        /// </summary>
        public static control_commandDelegate control_command;

        /// <summary>
        ///  n_set_rot_center(ushort n, int center_x, int center_y);
        /// </summary>
        public static n_set_rot_centerDelegate n_set_rot_center;

        /// <summary>
        ///  set_rot_center(int center_x, int center_y);
        /// </summary>
        public static set_rot_centerDelegate set_rot_center;

        /// <summary>
        ///  n_auto_change_pos(ushort n, int start);
        /// </summary>
        public static n_auto_change_posDelegate n_auto_change_pos;

        /// <summary>
        ///  auto_change_pos(int start);
        /// </summary>
        public static auto_change_posDelegate auto_change_pos;

        /// <summary>
        ///  short n_get_value(ushort n, ushort signal);
        /// </summary>
        public static n_get_valueDelegate n_get_value;

        /// <summary>
        ///  short get_value(ushort signal);
        /// </summary>
        public static get_valueDelegate get_value;

        /// <summary>
        ///  n_set_io_bit(ushort n, ushort mask1);
        /// </summary>
        public static n_set_io_bitDelegate n_set_io_bit;

        /// <summary>
        ///  set_io_bit(ushort mask1);
        /// </summary>
        public static set_io_bitDelegate set_io_bit;

        /// <summary>
        ///  n_clear_io_bit(ushort n, ushort mask0);
        /// </summary>
        public static n_clear_io_bitDelegate n_clear_io_bit;

        /// <summary>
        ///  clear_io_bit(ushort mask0);
        /// </summary>
        public static clear_io_bitDelegate clear_io_bit;

        /// <summary>
        ///  n_set_duty_cycle_table(ushort n, ushort index, ushort dutycycle);
        /// </summary>
        public static n_set_duty_cycle_tableDelegate n_set_duty_cycle_table;

        /// <summary>
        ///  set_duty_cycle_table(ushort index, ushort dutycycle);
        /// </summary>
        public static set_duty_cycle_tableDelegate set_duty_cycle_table;

        /// <summary>
        ///  n_set_laser_timing_table(ushort n, ushort index, double f);
        /// </summary>
        public static n_set_laser_timing_tableDelegate n_set_laser_timing_table;

        /// <summary>
        ///  set_laser_timing_table(ushort index, double f);
        /// </summary>
        public static set_laser_timing_tableDelegate set_laser_timing_table;

        /// <summary>
        ///  short n_store_on_mmc(ushort n);
        /// </summary>
        public static n_store_on_mmcDelegate n_store_on_mmc;

        /// <summary>
        ///  short store_on_mmc();
        /// </summary>
        public static store_on_mmcDelegate store_on_mmc;

        /// <summary>
        ///  ushort n_get_serial_number(ushort n);
        /// </summary>
        public static n_get_serial_numberDelegate n_get_serial_number;

        /// <summary>
        ///  ushort get_serial_number();
        /// </summary>
        public static get_serial_numberDelegate get_serial_number;

        /// <summary>
        ///  int n_get_serial_number_32(ushort n);
        /// </summary>
        public static n_get_serial_number_32Delegate n_get_serial_number_32;

        /// <summary>
        ///  int get_serial_number_32();
        /// </summary>
        public static get_serial_number_32Delegate get_serial_number_32;

        /// <summary>
        ///  n_measurement_status(ushort n, out ushort busy, out ushort position);
        /// </summary>
        public static n_measurement_statusDelegate n_measurement_status;

        /// <summary>
        ///  measurement_status(out ushort busy, out ushort position);
        /// </summary>
        public static measurement_statusDelegate measurement_status;

        /// <summary>
        ///  n_clear_list(ushort n);
        /// </summary>
        public static n_clear_listDelegate n_clear_list;

        /// <summary>
        ///  clear_list();
        /// </summary>
        public static clear_listDelegate clear_list;

        /// <summary>
        ///  n_set_char_table(ushort n, ushort ch, int listpos);
        /// </summary>
        public static n_set_char_tableDelegate n_set_char_table;

        /// <summary>
        ///  set_char_table(ushort ch, int listpos);
        /// </summary>
        public static set_char_tableDelegate set_char_table;

        /// <summary>
        ///  n_time_update(ushort n);
        /// </summary>
        public static n_time_updateDelegate n_time_update;

        /// <summary>
        ///  time_update();
        /// </summary>
        public static time_updateDelegate time_update;

        /// <summary>
        ///  n_set_serial(ushort n, int no);
        /// </summary>
        public static n_set_serialDelegate n_set_serial;

        /// <summary>
        ///  set_serial(int no);
        /// </summary>
        public static set_serialDelegate set_serial;

        /// <summary>
        ///  int n_memory_test(ushort n);
        /// </summary>
        public static n_memory_testDelegate n_memory_test;

        /// <summary>
        ///  int memory_test();
        /// </summary>
        public static memory_testDelegate memory_test;

        /// <summary>
        ///  n_list_nop(ushort n);
        /// </summary>
        public static n_list_nopDelegate n_list_nop;

        /// <summary>
        ///  list_nop();
        /// </summary>
        public static list_nopDelegate list_nop;

        /// <summary>
        ///  n_set_end_of_list(ushort n);
        /// </summary>
        public static n_set_end_of_listDelegate n_set_end_of_list;

        /// <summary>
        ///  set_end_of_list();
        /// </summary>
        public static set_end_of_listDelegate set_end_of_list;

        /// <summary>
        ///  n_jump_abs(ushort n, short x, short y);
        /// </summary>
        public static n_jump_absDelegate n_jump_abs;

        /// <summary>
        ///  jump_abs(short x, short y);
        /// </summary>
        public static jump_absDelegate jump_abs;

        /// <summary>
        ///  n_jump_abs_3d(ushort n, short x, short y, short z);
        /// </summary>
        public static n_jump_abs_3dDelegate n_jump_abs_3d;

        /// <summary>
        ///  jump_abs_3d(short x, short y, short z);
        /// </summary>
        public static jump_abs_3dDelegate jump_abs_3d;

        /// <summary>
        ///  n_mark_abs(ushort n, short x, short y);
        /// </summary>
        public static n_mark_absDelegate n_mark_abs;

        /// <summary>
        ///  mark_abs(short x, short y);
        /// </summary>
        public static mark_absDelegate mark_abs;

        /// <summary>
        ///  n_mark_abs_3d(ushort n, short x, short y, short z);
        /// </summary>
        public static n_mark_abs_3dDelegate n_mark_abs_3d;

        /// <summary>
        ///  mark_abs_3d(short x, short y, short z);
        /// </summary>
        public static mark_abs_3dDelegate mark_abs_3d;

        /// <summary>
        ///  n_jump_rel(ushort n, short dx, short dy);
        /// </summary>
        public static n_jump_relDelegate n_jump_rel;

        /// <summary>
        ///  jump_rel(short dx, short dy);
        /// </summary>
        public static jump_relDelegate jump_rel;

        /// <summary>
        ///  n_jump_rel_3d(ushort n, short dx, short dy, short dz);
        /// </summary>
        public static n_jump_rel_3dDelegate n_jump_rel_3d;

        /// <summary>
        ///  jump_rel_3d(short dx, short dy, short dz);
        /// </summary>
        public static jump_rel_3dDelegate jump_rel_3d;

        /// <summary>
        ///  n_mark_rel(ushort n, short dx, short dy);
        /// </summary>
        public static n_mark_relDelegate n_mark_rel;

        /// <summary>
        ///  mark_rel(short dx, short dy);
        /// </summary>
        public static mark_relDelegate mark_rel;

        /// <summary>
        ///  n_mark_rel_3d(ushort n, short dx, short dy, short dz);
        /// </summary>
        public static n_mark_rel_3dDelegate n_mark_rel_3d;

        /// <summary>
        ///  mark_rel_3d(short dx, short dy, short dz);
        /// </summary>
        public static mark_rel_3dDelegate mark_rel_3d;

        /// <summary>
        ///  n_write_8bit_port_list(ushort n, ushort value);
        /// </summary>
        public static n_write_8bit_port_listDelegate n_write_8bit_port_list;

        /// <summary>
        ///  write_8bit_port_list(ushort value);
        /// </summary>
        public static write_8bit_port_listDelegate write_8bit_port_list;

        /// <summary>
        ///  n_write_da_1_list(ushort n, ushort value);
        /// </summary>
        public static n_write_da_1_listDelegate n_write_da_1_list;

        /// <summary>
        ///  write_da_1_list(ushort value);
        /// </summary>
        public static write_da_1_listDelegate write_da_1_list;

        /// <summary>
        ///  n_write_da_2_list(ushort n, ushort value);
        /// </summary>
        public static n_write_da_2_listDelegate n_write_da_2_list;

        /// <summary>
        ///  write_da_2_list(ushort value);
        /// </summary>
        public static write_da_2_listDelegate write_da_2_list;

        /// <summary>
        ///  n_write_da_x_list(ushort n, ushort x, ushort value);
        /// </summary>
        public static n_write_da_x_listDelegate n_write_da_x_list;

        /// <summary>
        ///  write_da_x_list(ushort x, ushort value);
        /// </summary>
        public static write_da_x_listDelegate write_da_x_list;

        /// <summary>
        ///  n_set_offset_list(ushort n, short xoffset, short yoffset);
        /// </summary>
        public static n_set_offset_listDelegate n_set_offset_list;

        /// <summary>
        ///  set_offset_list(short xoffset, short yoffset);
        /// </summary>
        public static set_offset_listDelegate set_offset_list;

        /// <summary>
        ///  n_long_delay(ushort n, ushort value);
        /// </summary>
        public static n_long_delayDelegate n_long_delay;

        /// <summary>
        ///  long_delay(ushort value);
        /// </summary>
        public static long_delayDelegate long_delay;

        /// <summary>
        ///  n_laser_on_list(ushort n, ushort value);
        /// </summary>
        public static n_laser_on_listDelegate n_laser_on_list;

        /// <summary>
        ///  laser_on_list(ushort value);
        /// </summary>
        public static laser_on_listDelegate laser_on_list;

        /// <summary>
        ///  n_set_jump_speed(ushort n, double speed);
        /// </summary>
        public static n_set_jump_speedDelegate n_set_jump_speed;

        /// <summary>
        ///  set_jump_speed(double speed);
        /// </summary>
        public static set_jump_speedDelegate set_jump_speed;

        /// <summary>
        ///  n_set_mark_speed(ushort n, double speed);
        /// </summary>
        public static n_set_mark_speedDelegate n_set_mark_speed;

        /// <summary>
        ///  set_mark_speed(double speed);
        /// </summary>
        public static set_mark_speedDelegate set_mark_speed;

        /// <summary>
        ///  n_set_laser_delays(ushort n, short ondelay, short offdelay);
        /// </summary>
        public static n_set_laser_delaysDelegate n_set_laser_delays;

        /// <summary>
        ///  set_laser_delays(short ondelay, short offdelay);
        /// </summary>
        public static set_laser_delaysDelegate set_laser_delays;

        /// <summary>
        ///  n_set_scanner_delays(ushort n, ushort jumpdelay, ushort markdelay, ushort polydelay);
        /// </summary>
        public static n_set_scanner_delaysDelegate n_set_scanner_delays;

        /// <summary>
        ///  set_scanner_delays(ushort jumpdelay, ushort markdelay, ushort polydelay);
        /// </summary>
        public static set_scanner_delaysDelegate set_scanner_delays;

        /// <summary>
        ///  n_set_list_jump(ushort n, int position);
        /// </summary>
        public static n_set_list_jumpDelegate n_set_list_jump;

        /// <summary>
        ///  set_list_jump(int position);
        /// </summary>
        public static set_list_jumpDelegate set_list_jump;

        /// <summary>
        ///  n_list_call(ushort n, int position);
        /// </summary>
        public static n_list_callDelegate n_list_call;

        /// <summary>
        ///  list_call(int position);
        /// </summary>
        public static list_callDelegate list_call;

        /// <summary>
        ///  n_list_return(ushort n);
        /// </summary>
        public static n_list_returnDelegate n_list_return;

        /// <summary>
        ///  list_return();
        /// </summary>
        public static list_returnDelegate list_return;

        /// <summary>
        ///  n_z_out_list(ushort n, short z);
        /// </summary>
        public static n_z_out_listDelegate n_z_out_list;

        /// <summary>
        ///  z_out_list(short z);
        /// </summary>
        public static z_out_listDelegate z_out_list;

        /// <summary>
        ///  n_set_standby_list(ushort n, ushort half_period, ushort pulse);
        /// </summary>
        public static n_set_standby_listDelegate n_set_standby_list;

        /// <summary>
        ///  set_standby_list(ushort half_period, ushort pulse);
        /// </summary>
        public static set_standby_listDelegate set_standby_list;

        /// <summary>
        ///  n_timed_jump_abs(ushort n, short x, short y, double time);
        /// </summary>
        public static n_timed_jump_absDelegate n_timed_jump_abs;

        /// <summary>
        ///  timed_jump_abs(short x, short y, double time);
        /// </summary>
        public static timed_jump_absDelegate timed_jump_abs;

        /// <summary>
        ///  n_timed_mark_abs(ushort n, short x, short y, double time);
        /// </summary>
        public static n_timed_mark_absDelegate n_timed_mark_abs;

        /// <summary>
        ///  timed_mark_abs(short x, short y, double time);
        /// </summary>
        public static timed_mark_absDelegate timed_mark_abs;

        /// <summary>
        ///  n_timed_jump_rel(ushort n, short dx, short dy, double time);
        /// </summary>
        public static n_timed_jump_relDelegate n_timed_jump_rel;

        /// <summary>
        ///  timed_jump_rel(short dx, short dy, double time);
        /// </summary>
        public static timed_jump_relDelegate timed_jump_rel;

        /// <summary>
        ///  n_timed_mark_rel(ushort n, short dx, short dy, double time);
        /// </summary>
        public static n_timed_mark_relDelegate n_timed_mark_rel;

        /// <summary>
        ///  timed_mark_rel(short dx, short dy, double time);
        /// </summary>
        public static timed_mark_relDelegate timed_mark_rel;

        /// <summary>
        ///  n_set_laser_timing(ushort n, ushort halfperiod, ushort pulse1, ushort pulse2, ushort timebase);
        /// </summary>
        public static n_set_laser_timingDelegate n_set_laser_timing;

        /// <summary>
        ///  set_laser_timing(ushort halfperiod, ushort pulse1, ushort pulse2, ushort timebase);
        /// </summary>
        public static set_laser_timingDelegate set_laser_timing;

        /// <summary>
        ///  n_set_wobbel(ushort n, ushort amplitude, double frequency);
        /// </summary>
        public static n_set_wobbelDelegate n_set_wobbel;

        /// <summary>
        ///  set_wobbel(ushort amplitude, double frequency);
        /// </summary>
        public static set_wobbelDelegate set_wobbel;

        /// <summary>
        ///  n_set_fly_x(ushort n, double kx);
        /// </summary>
        public static n_set_fly_xDelegate n_set_fly_x;

        /// <summary>
        ///  set_fly_x(double kx);
        /// </summary>
        public static set_fly_xDelegate set_fly_x;

        /// <summary>
        ///  n_set_fly_y(ushort n, double ky);
        /// </summary>
        public static n_set_fly_yDelegate n_set_fly_y;

        /// <summary>
        ///  set_fly_y(double ky);
        /// </summary>
        public static set_fly_yDelegate set_fly_y;

        /// <summary>
        ///  n_write_io_port_list(ushort n, ushort value);
        /// </summary>
        public static n_write_io_port_listDelegate n_write_io_port_list;

        /// <summary>
        ///  write_io_port_list(ushort value);
        /// </summary>
        public static write_io_port_listDelegate write_io_port_list;

        /// <summary>
        ///  n_set_wait(ushort n, ushort value);
        /// </summary>
        public static n_set_waitDelegate n_set_wait;

        /// <summary>
        ///  set_wait(ushort value);
        /// </summary>
        public static set_waitDelegate set_wait;

        /// <summary>
        ///  n_simulate_ext_start(ushort n, short delay, short encoder);
        /// </summary>
        public static n_simulate_ext_startDelegate n_simulate_ext_start;

        /// <summary>
        ///  simulate_ext_start(short delay, short encoder);
        /// </summary>
        public static simulate_ext_startDelegate simulate_ext_start;

        /// <summary>
        ///  n_set_pixel_line(ushort n, ushort pixelmode, ushort pixelperiod, double dx, double dy);
        /// </summary>
        public static n_set_pixel_lineDelegate n_set_pixel_line;

        /// <summary>
        ///  set_pixel_line(ushort pixelmode, ushort pixelperiod, double dx, double dy);
        /// </summary>
        public static set_pixel_lineDelegate set_pixel_line;

        /// <summary>
        ///  n_set_pixel(ushort n, ushort pulswidth, ushort davalue, ushort dummy);
        /// </summary>
        public static n_set_pixelDelegate n_set_pixel;

        /// <summary>
        ///  set_pixel(ushort pulswidth, ushort davalue, ushort dummy);
        /// </summary>
        public static set_pixelDelegate set_pixel;

        /// <summary>
        ///  n_set_extstartpos_list(ushort n, int position);
        /// </summary>
        public static n_set_extstartpos_listDelegate n_set_extstartpos_list;

        /// <summary>
        ///  set_extstartpos_list(int position);
        /// </summary>
        public static set_extstartpos_listDelegate set_extstartpos_list;

        /// <summary>
        ///  n_laser_signal_on_list(ushort n);
        /// </summary>
        public static n_laser_signal_on_listDelegate n_laser_signal_on_list;

        /// <summary>
        ///  laser_signal_on_list();
        /// </summary>
        public static laser_signal_on_listDelegate laser_signal_on_list;

        /// <summary>
        ///  n_laser_signal_off_list(ushort n);
        /// </summary>
        public static n_laser_signal_off_listDelegate n_laser_signal_off_list;

        /// <summary>
        ///  laser_signal_off_list();
        /// </summary>
        public static laser_signal_off_listDelegate laser_signal_off_list;

        /// <summary>
        ///  n_set_firstpulse_killer_list(ushort n, ushort fpk);
        /// </summary>
        public static n_set_firstpulse_killer_listDelegate n_set_firstpulse_killer_list;

        /// <summary>
        ///  set_firstpulse_killer_list(ushort fpk);
        /// </summary>
        public static set_firstpulse_killer_listDelegate set_firstpulse_killer_list;

        /// <summary>
        ///  n_set_io_cond_list(ushort n, ushort mask_1, ushort mask_0, ushort mask_set);
        /// </summary>
        public static n_set_io_cond_listDelegate n_set_io_cond_list;

        /// <summary>
        ///  set_io_cond_list(ushort mask_1, ushort mask_0, ushort mask_set);
        /// </summary>
        public static set_io_cond_listDelegate set_io_cond_list;

        /// <summary>
        ///  n_clear_io_cond_list(ushort n, ushort mask_1, ushort mask_0, ushort mask_clear);
        /// </summary>
        public static n_clear_io_cond_listDelegate n_clear_io_cond_list;

        /// <summary>
        ///  clear_io_cond_list(ushort mask_1, ushort mask_0, ushort mask_clear);
        /// </summary>
        public static clear_io_cond_listDelegate clear_io_cond_list;

        /// <summary>
        ///  n_list_jump_cond(ushort n, ushort mask_1, ushort mask_0, int position);
        /// </summary>
        public static n_list_jump_condDelegate n_list_jump_cond;

        /// <summary>
        ///  list_jump_cond(ushort mask_1, ushort mask_0, int position);
        /// </summary>
        public static list_jump_condDelegate list_jump_cond;

        /// <summary>
        ///  n_list_call_cond(ushort n, ushort mask_1, ushort mask_0, int position);
        /// </summary>
        public static n_list_call_condDelegate n_list_call_cond;

        /// <summary>
        ///  list_call_cond(ushort mask_1, ushort mask_0, int position);
        /// </summary>
        public static list_call_condDelegate list_call_cond;

        /// <summary>
        ///  n_save_and_restart_timer(ushort n);
        /// </summary>
        public static n_save_and_restart_timerDelegate n_save_and_restart_timer;

        /// <summary>
        ///  save_and_restart_timer();
        /// </summary>
        public static save_and_restart_timerDelegate save_and_restart_timer;

        /// <summary>
        ///  n_set_matrix_list(ushort n, ushort i, ushort j, double mij);
        /// </summary>
        public static n_set_matrix_listDelegate n_set_matrix_list;

        /// <summary>
        ///  set_matrix_list(ushort i, ushort j, double mij);
        /// </summary>
        public static set_matrix_listDelegate set_matrix_list;

        /// <summary>
        ///  n_set_control_mode_list(ushort n, ushort mode);
        /// </summary>
        public static n_set_control_mode_listDelegate n_set_control_mode_list;

        /// <summary>
        ///  set_control_mode_list(ushort mode);
        /// </summary>
        public static set_control_mode_listDelegate set_control_mode_list;

        /// <summary>
        ///  n_set_defocus_list(ushort n, short value);
        /// </summary>
        public static n_set_defocus_listDelegate n_set_defocus_list;

        /// <summary>
        ///  set_defocus_list(short value);
        /// </summary>
        public static set_defocus_listDelegate set_defocus_list;

        /// <summary>
        ///  n_set_ext_start_delay_list(ushort n, short delay, short encoder);
        /// </summary>
        public static n_set_ext_start_delay_listDelegate n_set_ext_start_delay_list;

        /// <summary>
        ///  set_ext_start_delay_list(short delay, short encoder);
        /// </summary>
        public static set_ext_start_delay_listDelegate set_ext_start_delay_list;

        /// <summary>
        ///  n_set_wobbel_xy(ushort n, ushort long_wob, ushort trans_wob, double frequency);
        /// </summary>
        public static n_set_wobbel_xyDelegate n_set_wobbel_xy;

        /// <summary>
        ///  set_wobbel_xy(ushort long_wob, ushort trans_wob, double frequency);
        /// </summary>
        public static set_wobbel_xyDelegate set_wobbel_xy;

        /// <summary>
        ///  n_calculate_fly(ushort n, ushort direction, double distance);
        /// </summary>
        public static n_calculate_flyDelegate n_calculate_fly;

        /// <summary>
        ///  calculate_fly(ushort direction, double distance);
        /// </summary>
        public static calculate_flyDelegate calculate_fly;

        /// <summary>
        ///  n_select_cor_table_list(ushort n, ushort heada, ushort headb);
        /// </summary>
        public static n_select_cor_table_listDelegate n_select_cor_table_list;

        /// <summary>
        ///  select_cor_table_list(ushort heada, ushort headb);
        /// </summary>
        public static select_cor_table_listDelegate select_cor_table_list;

        /// <summary>
        ///  n_set_fly_rot(ushort n, double resolution);
        /// </summary>
        public static n_set_fly_rotDelegate n_set_fly_rot;

        /// <summary>
        ///  set_fly_rot(double resolution);
        /// </summary>
        public static set_fly_rotDelegate set_fly_rot;

        /// <summary>
        ///  n_fly_return(ushort n, short x, short y);
        /// </summary>
        public static n_fly_returnDelegate n_fly_return;

        /// <summary>
        ///  fly_return(short x, short y);
        /// </summary>
        public static fly_returnDelegate fly_return;

        /// <summary>
        ///  n_set_trigger(ushort n, ushort sampleperiod, ushort channel1, ushort channel2);
        /// </summary>
        public static n_set_triggerDelegate n_set_trigger;

        /// <summary>
        ///  set_trigger(ushort sampleperiod, ushort channel1, ushort channel2);
        /// </summary>
        public static set_triggerDelegate set_trigger;

        /// <summary>
        ///  n_arc_rel(ushort n, short dx, short dy, double angle);
        /// </summary>
        public static n_arc_relDelegate n_arc_rel;

        /// <summary>
        ///  arc_rel(short dx, short dy, double angle);
        /// </summary>
        public static arc_relDelegate arc_rel;

        /// <summary>
        ///  n_arc_abs(ushort n, short x, short y, double angle);
        /// </summary>
        public static n_arc_absDelegate n_arc_abs;

        /// <summary>
        ///  arc_abs(short x, short y, double angle);
        /// </summary>
        public static arc_absDelegate arc_abs;

        /// <summary>
        ///  n_time_fix(ushort n);
        /// </summary>
        public static n_time_fixDelegate n_time_fix;

        /// <summary>
        ///  time_fix();
        /// </summary>
        public static time_fixDelegate time_fix;

        /// <summary>
        ///  n_time_fix_f(ushort n, ushort mode);
        /// </summary>
        public static n_time_fix_fDelegate n_time_fix_f;

        /// <summary>
        ///  time_fix_f(ushort mode);
        /// </summary>
        public static time_fix_fDelegate time_fix_f;

        /// <summary>
        ///  n_mark_time(ushort n, ushort part, ushort mode);
        /// </summary>
        public static n_mark_timeDelegate n_mark_time;

        /// <summary>
        ///  mark_time(ushort part, ushort mode);
        /// </summary>
        public static mark_timeDelegate mark_time;

        /// <summary>
        ///  n_mark_date(ushort n, ushort part, ushort mode);
        /// </summary>
        public static n_mark_dateDelegate n_mark_date;

        /// <summary>
        ///  mark_date(ushort part, ushort mode);
        /// </summary>
        public static mark_dateDelegate mark_date;

        /// <summary>
        ///  n_mark_serial(ushort n, ushort mode, ushort digits);
        /// </summary>
        public static n_mark_serialDelegate n_mark_serial;

        /// <summary>
        ///  mark_serial(ushort mode, ushort digits);
        /// </summary>
        public static mark_serialDelegate mark_serial;

        /// <summary>
        ///  n_date_check(ushort n, ushort month1, ushort month2, ushort month3);
        /// </summary>
        public static n_date_checkDelegate n_date_check;

        /// <summary>
        ///  date_check(ushort month1, ushort month2, ushort month3);
        /// </summary>
        public static date_checkDelegate date_check;

        /// <summary>
        ///  n_flyline(ushort n, short encoderdelay);
        /// </summary>
        public static n_flylineDelegate n_flyline;

        /// <summary>
        ///  flyline(short encoderdelay);
        /// </summary>
        public static flylineDelegate flyline;

        /// <summary>
        ///  n_drilling(ushort n, short pulsewidth, short relencoderdelay);
        /// </summary>
        public static n_drillingDelegate n_drilling;

        /// <summary>
        ///  drilling(short pulsewidth, short relencoderdelay);
        /// </summary>
        public static drillingDelegate drilling;

        /// <summary>
        ///  n_regulation(ushort n);
        /// </summary>
        public static n_regulationDelegate n_regulation;

        /// <summary>
        ///  regulation();
        /// </summary>
        public static regulationDelegate regulation;

        /// <summary>
        ///  n_regulation2(ushort n, double fmax, double fmin);
        /// </summary>
        public static n_regulation2Delegate n_regulation2;

        /// <summary>
        ///  regulation2(double fmax, double fmin);
        /// </summary>
        public static regulation2Delegate regulation2;

        /// <summary>
        ///  n_regulation3(ushort n, double fmax, double fmin);
        /// </summary>
        public static n_regulation3Delegate n_regulation3;

        /// <summary>
        ///  regulation3(double fmax, double fmin);
        /// </summary>
        public static regulation3Delegate regulation3;

        /// <summary>
        ///  n_store_encoder(ushort n);
        /// </summary>
        public static n_store_encoderDelegate n_store_encoder;

        /// <summary>
        ///  store_encoder();
        /// </summary>
        public static store_encoderDelegate store_encoder;

        /// <summary>
        ///  n_fly_displacement_ret(ushort n, short x, short y);
        /// </summary>
        public static n_fly_displacement_retDelegate n_fly_displacement_ret;

        /// <summary>
        ///  fly_displacement_ret(short x, short y);
        /// </summary>
        public static fly_displacement_retDelegate fly_displacement_ret;

        /// <summary>
        ///  int usb_reinitialize(out int foundcards);
        /// </summary>
        public static usb_reinitializeDelegate usb_reinitialize;

        #endregion

        // Notice that the static constructor is used to initialize any static data,
        //    or to perform a particular action that needs to be performed once only.
        //    It is called automatically before the first instance is created or any
        //    static members are referenced.
        static SCANalone4Wrap()
        {
            // Import functions and set them up as delegates.
            //
            #region DLLFunctionImport
            scanalone_count_cards = (scanalone_count_cardsDelegate)FunctionImporter.Import<scanalone_count_cardsDelegate>("scanalone_count_cards");
            select_rtc = (select_rtcDelegate)FunctionImporter.Import<select_rtcDelegate>("select_rtc");
            n_usb_status = (n_usb_statusDelegate)FunctionImporter.Import<n_usb_statusDelegate>("n_usb_status");
            usb_status = (usb_statusDelegate)FunctionImporter.Import<usb_statusDelegate>("usb_status");
            n_load_correction_file = (n_load_correction_fileDelegate)FunctionImporter.Import<n_load_correction_fileDelegate>("n_load_correction_file");
            load_correction_file = (load_correction_fileDelegate)FunctionImporter.Import<load_correction_fileDelegate>("load_correction_file");
            n_load_cor = (n_load_corDelegate)FunctionImporter.Import<n_load_corDelegate>("n_load_cor");
            load_cor = (load_corDelegate)FunctionImporter.Import<load_corDelegate>("load_cor");
            n_stop_execution = (n_stop_executionDelegate)FunctionImporter.Import<n_stop_executionDelegate>("n_stop_execution");
            n_load_program_file = (n_load_program_fileDelegate)FunctionImporter.Import<n_load_program_fileDelegate>("n_load_program_file");
            load_program_file = (load_program_fileDelegate)FunctionImporter.Import<load_program_fileDelegate>("load_program_file");
            n_load_pro = (n_load_proDelegate)FunctionImporter.Import<n_load_proDelegate>("n_load_pro");
            load_pro = (load_proDelegate)FunctionImporter.Import<load_proDelegate>("load_pro");
            n_load_varpolydelay = (n_load_varpolydelayDelegate)FunctionImporter.Import<n_load_varpolydelayDelegate>("n_load_varpolydelay");
            load_varpolydelay = (load_varpolydelayDelegate)FunctionImporter.Import<load_varpolydelayDelegate>("load_varpolydelay");
            n_load_z_table = (n_load_z_tableDelegate)FunctionImporter.Import<n_load_z_tableDelegate>("n_load_z_table");
            load_z_table = (load_z_tableDelegate)FunctionImporter.Import<load_z_tableDelegate>("load_z_table");
            n_get_waveform = (n_get_waveformDelegate)FunctionImporter.Import<n_get_waveformDelegate>("n_get_waveform");
            get_waveform = (get_waveformDelegate)FunctionImporter.Import<get_waveformDelegate>("get_waveform");
            n_get_status = (n_get_statusDelegate)FunctionImporter.Import<n_get_statusDelegate>("n_get_status");
            get_status = (get_statusDelegate)FunctionImporter.Import<get_statusDelegate>("get_status");
            n_read_status = (n_read_statusDelegate)FunctionImporter.Import<n_read_statusDelegate>("n_read_status");
            read_status = (read_statusDelegate)FunctionImporter.Import<read_statusDelegate>("read_status");
            get_dll_version = (get_dll_versionDelegate)FunctionImporter.Import<get_dll_versionDelegate>("get_dll_version");
            n_get_input_pointer = (n_get_input_pointerDelegate)FunctionImporter.Import<n_get_input_pointerDelegate>("n_get_input_pointer");
            get_input_pointer = (get_input_pointerDelegate)FunctionImporter.Import<get_input_pointerDelegate>("get_input_pointer");
            n_set_input_pointer = (n_set_input_pointerDelegate)FunctionImporter.Import<n_set_input_pointerDelegate>("n_set_input_pointer");
            set_input_pointer = (set_input_pointerDelegate)FunctionImporter.Import<set_input_pointerDelegate>("set_input_pointer");
            n_set_start_list_1 = (n_set_start_list_1Delegate)FunctionImporter.Import<n_set_start_list_1Delegate>("n_set_start_list_1");
            set_start_list_1 = (set_start_list_1Delegate)FunctionImporter.Import<set_start_list_1Delegate>("set_start_list_1");
            n_set_start_list_2 = (n_set_start_list_2Delegate)FunctionImporter.Import<n_set_start_list_2Delegate>("n_set_start_list_2");
            set_start_list_2 = (set_start_list_2Delegate)FunctionImporter.Import<set_start_list_2Delegate>("set_start_list_2");
            n_set_start_list = (n_set_start_listDelegate)FunctionImporter.Import<n_set_start_listDelegate>("n_set_start_list");
            set_start_list = (set_start_listDelegate)FunctionImporter.Import<set_start_listDelegate>("set_start_list");
            n_execute_list_1 = (n_execute_list_1Delegate)FunctionImporter.Import<n_execute_list_1Delegate>("n_execute_list_1");
            execute_list_1 = (execute_list_1Delegate)FunctionImporter.Import<execute_list_1Delegate>("execute_list_1");
            n_execute_list_2 = (n_execute_list_2Delegate)FunctionImporter.Import<n_execute_list_2Delegate>("n_execute_list_2");
            execute_list_2 = (execute_list_2Delegate)FunctionImporter.Import<execute_list_2Delegate>("execute_list_2");
            n_execute_list = (n_execute_listDelegate)FunctionImporter.Import<n_execute_listDelegate>("n_execute_list");
            execute_list = (execute_listDelegate)FunctionImporter.Import<execute_listDelegate>("execute_list");
            n_write_8bit_port = (n_write_8bit_portDelegate)FunctionImporter.Import<n_write_8bit_portDelegate>("n_write_8bit_port");
            write_8bit_port = (write_8bit_portDelegate)FunctionImporter.Import<write_8bit_portDelegate>("write_8bit_port");
            n_write_io_port = (n_write_io_portDelegate)FunctionImporter.Import<n_write_io_portDelegate>("n_write_io_port");
            write_io_port = (write_io_portDelegate)FunctionImporter.Import<write_io_portDelegate>("write_io_port");
            n_auto_change = (n_auto_changeDelegate)FunctionImporter.Import<n_auto_changeDelegate>("n_auto_change");
            auto_change = (auto_changeDelegate)FunctionImporter.Import<auto_changeDelegate>("auto_change");
            n_aut_change = (n_aut_changeDelegate)FunctionImporter.Import<n_aut_changeDelegate>("n_aut_change");
            aut_change = (aut_changeDelegate)FunctionImporter.Import<aut_changeDelegate>("aut_change");
            n_start_loop = (n_start_loopDelegate)FunctionImporter.Import<n_start_loopDelegate>("n_start_loop");
            start_loop = (start_loopDelegate)FunctionImporter.Import<start_loopDelegate>("start_loop");
            n_quit_loop = (n_quit_loopDelegate)FunctionImporter.Import<n_quit_loopDelegate>("n_quit_loop");
            quit_loop = (quit_loopDelegate)FunctionImporter.Import<quit_loopDelegate>("quit_loop");
            stop_execution = (stop_executionDelegate)FunctionImporter.Import<stop_executionDelegate>("stop_execution");
            n_dsp_start = (n_dsp_startDelegate)FunctionImporter.Import<n_dsp_startDelegate>("n_dsp_start");
            dsp_start = (dsp_startDelegate)FunctionImporter.Import<dsp_startDelegate>("dsp_start");
            n_read_io_port = (n_read_io_portDelegate)FunctionImporter.Import<n_read_io_portDelegate>("n_read_io_port");
            read_io_port = (read_io_portDelegate)FunctionImporter.Import<read_io_portDelegate>("read_io_port");
            n_write_da_1 = (n_write_da_1Delegate)FunctionImporter.Import<n_write_da_1Delegate>("n_write_da_1");
            write_da_1 = (write_da_1Delegate)FunctionImporter.Import<write_da_1Delegate>("write_da_1");
            n_write_da_2 = (n_write_da_2Delegate)FunctionImporter.Import<n_write_da_2Delegate>("n_write_da_2");
            write_da_2 = (write_da_2Delegate)FunctionImporter.Import<write_da_2Delegate>("write_da_2");
            n_write_da_x = (n_write_da_xDelegate)FunctionImporter.Import<n_write_da_xDelegate>("n_write_da_x");
            write_da_x = (write_da_xDelegate)FunctionImporter.Import<write_da_xDelegate>("write_da_x");
            n_set_max_counts = (n_set_max_countsDelegate)FunctionImporter.Import<n_set_max_countsDelegate>("n_set_max_counts");
            set_max_counts = (set_max_countsDelegate)FunctionImporter.Import<set_max_countsDelegate>("set_max_counts");
            n_get_counts = (n_get_countsDelegate)FunctionImporter.Import<n_get_countsDelegate>("n_get_counts");
            get_counts = (get_countsDelegate)FunctionImporter.Import<get_countsDelegate>("get_counts");
            n_set_matrix = (n_set_matrixDelegate)FunctionImporter.Import<n_set_matrixDelegate>("n_set_matrix");
            set_matrix = (set_matrixDelegate)FunctionImporter.Import<set_matrixDelegate>("set_matrix");
            n_set_offset = (n_set_offsetDelegate)FunctionImporter.Import<n_set_offsetDelegate>("n_set_offset");
            set_offset = (set_offsetDelegate)FunctionImporter.Import<set_offsetDelegate>("set_offset");
            n_goto_xy = (n_goto_xyDelegate)FunctionImporter.Import<n_goto_xyDelegate>("n_goto_xy");
            goto_xy = (goto_xyDelegate)FunctionImporter.Import<goto_xyDelegate>("goto_xy");
            n_goto_xyz = (n_goto_xyzDelegate)FunctionImporter.Import<n_goto_xyzDelegate>("n_goto_xyz");
            goto_xyz = (goto_xyzDelegate)FunctionImporter.Import<goto_xyzDelegate>("goto_xyz");
            n_get_hex_version = (n_get_hex_versionDelegate)FunctionImporter.Import<n_get_hex_versionDelegate>("n_get_hex_version");
            get_hex_version = (get_hex_versionDelegate)FunctionImporter.Import<get_hex_versionDelegate>("get_hex_version");
            n_enable_laser = (n_enable_laserDelegate)FunctionImporter.Import<n_enable_laserDelegate>("n_enable_laser");
            enable_laser = (enable_laserDelegate)FunctionImporter.Import<enable_laserDelegate>("enable_laser");
            n_disable_laser = (n_disable_laserDelegate)FunctionImporter.Import<n_disable_laserDelegate>("n_disable_laser");
            disable_laser = (disable_laserDelegate)FunctionImporter.Import<disable_laserDelegate>("disable_laser");
            n_stop_list = (n_stop_listDelegate)FunctionImporter.Import<n_stop_listDelegate>("n_stop_list");
            stop_list = (stop_listDelegate)FunctionImporter.Import<stop_listDelegate>("stop_list");
            n_restart_list = (n_restart_listDelegate)FunctionImporter.Import<n_restart_listDelegate>("n_restart_list");
            restart_list = (restart_listDelegate)FunctionImporter.Import<restart_listDelegate>("restart_list");
            n_get_rtc_version = (n_get_rtc_versionDelegate)FunctionImporter.Import<n_get_rtc_versionDelegate>("n_get_rtc_version");
            get_rtc_version = (get_rtc_versionDelegate)FunctionImporter.Import<get_rtc_versionDelegate>("get_rtc_version");
            n_get_xy_pos = (n_get_xy_posDelegate)FunctionImporter.Import<n_get_xy_posDelegate>("n_get_xy_pos");
            get_xy_pos = (get_xy_posDelegate)FunctionImporter.Import<get_xy_posDelegate>("get_xy_pos");
            n_get_xyz_pos = (n_get_xyz_posDelegate)FunctionImporter.Import<n_get_xyz_posDelegate>("n_get_xyz_pos");
            get_xyz_pos = (get_xyz_posDelegate)FunctionImporter.Import<get_xyz_posDelegate>("get_xyz_pos");
            n_select_list = (n_select_listDelegate)FunctionImporter.Import<n_select_listDelegate>("n_select_list");
            select_list = (select_listDelegate)FunctionImporter.Import<select_listDelegate>("select_list");
            n_set_extstartpos = (n_set_extstartposDelegate)FunctionImporter.Import<n_set_extstartposDelegate>("n_set_extstartpos");
            set_extstartpos = (set_extstartposDelegate)FunctionImporter.Import<set_extstartposDelegate>("set_extstartpos");
            n_z_out = (n_z_outDelegate)FunctionImporter.Import<n_z_outDelegate>("n_z_out");
            z_out = (z_outDelegate)FunctionImporter.Import<z_outDelegate>("z_out");
            n_set_firstpulse_killer = (n_set_firstpulse_killerDelegate)FunctionImporter.Import<n_set_firstpulse_killerDelegate>("n_set_firstpulse_killer");
            set_firstpulse_killer = (set_firstpulse_killerDelegate)FunctionImporter.Import<set_firstpulse_killerDelegate>("set_firstpulse_killer");
            n_set_standby = (n_set_standbyDelegate)FunctionImporter.Import<n_set_standbyDelegate>("n_set_standby");
            set_standby = (set_standbyDelegate)FunctionImporter.Import<set_standbyDelegate>("set_standby");
            n_laser_signal_on = (n_laser_signal_onDelegate)FunctionImporter.Import<n_laser_signal_onDelegate>("n_laser_signal_on");
            laser_signal_on = (laser_signal_onDelegate)FunctionImporter.Import<laser_signal_onDelegate>("laser_signal_on");
            n_laser_signal_off = (n_laser_signal_offDelegate)FunctionImporter.Import<n_laser_signal_offDelegate>("n_laser_signal_off");
            laser_signal_off = (laser_signal_offDelegate)FunctionImporter.Import<laser_signal_offDelegate>("laser_signal_off");
            n_set_delay_mode = (n_set_delay_modeDelegate)FunctionImporter.Import<n_set_delay_modeDelegate>("n_set_delay_mode");
            set_delay_mode = (set_delay_modeDelegate)FunctionImporter.Import<set_delay_modeDelegate>("set_delay_mode");
            n_set_piso_control = (n_set_piso_controlDelegate)FunctionImporter.Import<n_set_piso_controlDelegate>("n_set_piso_control");
            set_piso_control = (set_piso_controlDelegate)FunctionImporter.Import<set_piso_controlDelegate>("set_piso_control");
            n_select_status = (n_select_statusDelegate)FunctionImporter.Import<n_select_statusDelegate>("n_select_status");
            select_status = (select_statusDelegate)FunctionImporter.Import<select_statusDelegate>("select_status");
            n_get_encoder = (n_get_encoderDelegate)FunctionImporter.Import<n_get_encoderDelegate>("n_get_encoder");
            get_encoder = (get_encoderDelegate)FunctionImporter.Import<get_encoderDelegate>("get_encoder");
            n_select_cor_table = (n_select_cor_tableDelegate)FunctionImporter.Import<n_select_cor_tableDelegate>("n_select_cor_table");
            select_cor_table = (select_cor_tableDelegate)FunctionImporter.Import<select_cor_tableDelegate>("select_cor_table");
            n_execute_at_pointer = (n_execute_at_pointerDelegate)FunctionImporter.Import<n_execute_at_pointerDelegate>("n_execute_at_pointer");
            execute_at_pointer = (execute_at_pointerDelegate)FunctionImporter.Import<execute_at_pointerDelegate>("execute_at_pointer");
            n_get_head_status = (n_get_head_statusDelegate)FunctionImporter.Import<n_get_head_statusDelegate>("n_get_head_status");
            get_head_status = (get_head_statusDelegate)FunctionImporter.Import<get_head_statusDelegate>("get_head_status");
            n_simulate_encoder = (n_simulate_encoderDelegate)FunctionImporter.Import<n_simulate_encoderDelegate>("n_simulate_encoder");
            simulate_encoder = (simulate_encoderDelegate)FunctionImporter.Import<simulate_encoderDelegate>("simulate_encoder");
            n_release_wait = (n_release_waitDelegate)FunctionImporter.Import<n_release_waitDelegate>("n_release_wait");
            release_wait = (release_waitDelegate)FunctionImporter.Import<release_waitDelegate>("release_wait");
            n_get_wait_status = (n_get_wait_statusDelegate)FunctionImporter.Import<n_get_wait_statusDelegate>("n_get_wait_status");
            get_wait_status = (get_wait_statusDelegate)FunctionImporter.Import<get_wait_statusDelegate>("get_wait_status");
            n_set_control_mode = (n_set_control_modeDelegate)FunctionImporter.Import<n_set_control_modeDelegate>("n_set_control_mode");
            set_control_mode = (set_control_modeDelegate)FunctionImporter.Import<set_control_modeDelegate>("set_control_mode");
            n_set_laser_mode = (n_set_laser_modeDelegate)FunctionImporter.Import<n_set_laser_modeDelegate>("n_set_laser_mode");
            set_laser_mode = (set_laser_modeDelegate)FunctionImporter.Import<set_laser_modeDelegate>("set_laser_mode");
            n_set_ext_start_delay = (n_set_ext_start_delayDelegate)FunctionImporter.Import<n_set_ext_start_delayDelegate>("n_set_ext_start_delay");
            set_ext_start_delay = (set_ext_start_delayDelegate)FunctionImporter.Import<set_ext_start_delayDelegate>("set_ext_start_delay");
            n_home_position = (n_home_positionDelegate)FunctionImporter.Import<n_home_positionDelegate>("n_home_position");
            home_position = (home_positionDelegate)FunctionImporter.Import<home_positionDelegate>("home_position");
            n_read_ad_x = (n_read_ad_xDelegate)FunctionImporter.Import<n_read_ad_xDelegate>("n_read_ad_x");
            read_ad_x = (read_ad_xDelegate)FunctionImporter.Import<read_ad_xDelegate>("read_ad_x");
            n_get_z_distance = (n_get_z_distanceDelegate)FunctionImporter.Import<n_get_z_distanceDelegate>("n_get_z_distance");
            get_z_distance = (get_z_distanceDelegate)FunctionImporter.Import<get_z_distanceDelegate>("get_z_distance");
            n_get_startstop_info = (n_get_startstop_infoDelegate)FunctionImporter.Import<n_get_startstop_infoDelegate>("n_get_startstop_info");
            get_startstop_info = (get_startstop_infoDelegate)FunctionImporter.Import<get_startstop_infoDelegate>("get_startstop_info");
            n_get_marking_info = (n_get_marking_infoDelegate)FunctionImporter.Import<n_get_marking_infoDelegate>("n_get_marking_info");
            get_marking_info = (get_marking_infoDelegate)FunctionImporter.Import<get_marking_infoDelegate>("get_marking_info");
            n_get_io_status = (n_get_io_statusDelegate)FunctionImporter.Import<n_get_io_statusDelegate>("n_get_io_status");
            get_io_status = (get_io_statusDelegate)FunctionImporter.Import<get_io_statusDelegate>("get_io_status");
            n_get_time = (n_get_timeDelegate)FunctionImporter.Import<n_get_timeDelegate>("n_get_time");
            get_time = (get_timeDelegate)FunctionImporter.Import<get_timeDelegate>("get_time");
            n_set_defocus = (n_set_defocusDelegate)FunctionImporter.Import<n_set_defocusDelegate>("n_set_defocus");
            set_defocus = (set_defocusDelegate)FunctionImporter.Import<set_defocusDelegate>("set_defocus");
            n_set_softstart_mode = (n_set_softstart_modeDelegate)FunctionImporter.Import<n_set_softstart_modeDelegate>("n_set_softstart_mode");
            set_softstart_mode = (set_softstart_modeDelegate)FunctionImporter.Import<set_softstart_modeDelegate>("set_softstart_mode");
            n_set_softstart_level = (n_set_softstart_levelDelegate)FunctionImporter.Import<n_set_softstart_levelDelegate>("n_set_softstart_level");
            set_softstart_level = (set_softstart_levelDelegate)FunctionImporter.Import<set_softstart_levelDelegate>("set_softstart_level");
            n_control_command = (n_control_commandDelegate)FunctionImporter.Import<n_control_commandDelegate>("n_control_command");
            control_command = (control_commandDelegate)FunctionImporter.Import<control_commandDelegate>("control_command");
            n_set_rot_center = (n_set_rot_centerDelegate)FunctionImporter.Import<n_set_rot_centerDelegate>("n_set_rot_center");
            set_rot_center = (set_rot_centerDelegate)FunctionImporter.Import<set_rot_centerDelegate>("set_rot_center");
            n_auto_change_pos = (n_auto_change_posDelegate)FunctionImporter.Import<n_auto_change_posDelegate>("n_auto_change_pos");
            auto_change_pos = (auto_change_posDelegate)FunctionImporter.Import<auto_change_posDelegate>("auto_change_pos");
            n_get_value = (n_get_valueDelegate)FunctionImporter.Import<n_get_valueDelegate>("n_get_value");
            get_value = (get_valueDelegate)FunctionImporter.Import<get_valueDelegate>("get_value");
            n_set_io_bit = (n_set_io_bitDelegate)FunctionImporter.Import<n_set_io_bitDelegate>("n_set_io_bit");
            set_io_bit = (set_io_bitDelegate)FunctionImporter.Import<set_io_bitDelegate>("set_io_bit");
            n_clear_io_bit = (n_clear_io_bitDelegate)FunctionImporter.Import<n_clear_io_bitDelegate>("n_clear_io_bit");
            clear_io_bit = (clear_io_bitDelegate)FunctionImporter.Import<clear_io_bitDelegate>("clear_io_bit");
            n_set_duty_cycle_table = (n_set_duty_cycle_tableDelegate)FunctionImporter.Import<n_set_duty_cycle_tableDelegate>("n_set_duty_cycle_table");
            set_duty_cycle_table = (set_duty_cycle_tableDelegate)FunctionImporter.Import<set_duty_cycle_tableDelegate>("set_duty_cycle_table");
            n_set_laser_timing_table = (n_set_laser_timing_tableDelegate)FunctionImporter.Import<n_set_laser_timing_tableDelegate>("n_set_laser_timing_table");
            set_laser_timing_table = (set_laser_timing_tableDelegate)FunctionImporter.Import<set_laser_timing_tableDelegate>("set_laser_timing_table");
            n_store_on_mmc = (n_store_on_mmcDelegate)FunctionImporter.Import<n_store_on_mmcDelegate>("n_store_on_mmc");
            store_on_mmc = (store_on_mmcDelegate)FunctionImporter.Import<store_on_mmcDelegate>("store_on_mmc");
            n_get_serial_number = (n_get_serial_numberDelegate)FunctionImporter.Import<n_get_serial_numberDelegate>("n_get_serial_number");
            get_serial_number = (get_serial_numberDelegate)FunctionImporter.Import<get_serial_numberDelegate>("get_serial_number");
            n_get_serial_number_32 = (n_get_serial_number_32Delegate)FunctionImporter.Import<n_get_serial_number_32Delegate>("n_get_serial_number_32");
            get_serial_number_32 = (get_serial_number_32Delegate)FunctionImporter.Import<get_serial_number_32Delegate>("get_serial_number_32");
            n_measurement_status = (n_measurement_statusDelegate)FunctionImporter.Import<n_measurement_statusDelegate>("n_measurement_status");
            measurement_status = (measurement_statusDelegate)FunctionImporter.Import<measurement_statusDelegate>("measurement_status");
            n_clear_list = (n_clear_listDelegate)FunctionImporter.Import<n_clear_listDelegate>("n_clear_list");
            clear_list = (clear_listDelegate)FunctionImporter.Import<clear_listDelegate>("clear_list");
            n_set_char_table = (n_set_char_tableDelegate)FunctionImporter.Import<n_set_char_tableDelegate>("n_set_char_table");
            set_char_table = (set_char_tableDelegate)FunctionImporter.Import<set_char_tableDelegate>("set_char_table");
            n_time_update = (n_time_updateDelegate)FunctionImporter.Import<n_time_updateDelegate>("n_time_update");
            time_update = (time_updateDelegate)FunctionImporter.Import<time_updateDelegate>("time_update");
            n_set_serial = (n_set_serialDelegate)FunctionImporter.Import<n_set_serialDelegate>("n_set_serial");
            set_serial = (set_serialDelegate)FunctionImporter.Import<set_serialDelegate>("set_serial");
            n_memory_test = (n_memory_testDelegate)FunctionImporter.Import<n_memory_testDelegate>("n_memory_test");
            memory_test = (memory_testDelegate)FunctionImporter.Import<memory_testDelegate>("memory_test");
            n_list_nop = (n_list_nopDelegate)FunctionImporter.Import<n_list_nopDelegate>("n_list_nop");
            list_nop = (list_nopDelegate)FunctionImporter.Import<list_nopDelegate>("list_nop");
            n_set_end_of_list = (n_set_end_of_listDelegate)FunctionImporter.Import<n_set_end_of_listDelegate>("n_set_end_of_list");
            set_end_of_list = (set_end_of_listDelegate)FunctionImporter.Import<set_end_of_listDelegate>("set_end_of_list");
            n_jump_abs = (n_jump_absDelegate)FunctionImporter.Import<n_jump_absDelegate>("n_jump_abs");
            jump_abs = (jump_absDelegate)FunctionImporter.Import<jump_absDelegate>("jump_abs");
            n_jump_abs_3d = (n_jump_abs_3dDelegate)FunctionImporter.Import<n_jump_abs_3dDelegate>("n_jump_abs_3d");
            jump_abs_3d = (jump_abs_3dDelegate)FunctionImporter.Import<jump_abs_3dDelegate>("jump_abs_3d");
            n_mark_abs = (n_mark_absDelegate)FunctionImporter.Import<n_mark_absDelegate>("n_mark_abs");
            mark_abs = (mark_absDelegate)FunctionImporter.Import<mark_absDelegate>("mark_abs");
            n_mark_abs_3d = (n_mark_abs_3dDelegate)FunctionImporter.Import<n_mark_abs_3dDelegate>("n_mark_abs_3d");
            mark_abs_3d = (mark_abs_3dDelegate)FunctionImporter.Import<mark_abs_3dDelegate>("mark_abs_3d");
            n_jump_rel = (n_jump_relDelegate)FunctionImporter.Import<n_jump_relDelegate>("n_jump_rel");
            jump_rel = (jump_relDelegate)FunctionImporter.Import<jump_relDelegate>("jump_rel");
            n_jump_rel_3d = (n_jump_rel_3dDelegate)FunctionImporter.Import<n_jump_rel_3dDelegate>("n_jump_rel_3d");
            jump_rel_3d = (jump_rel_3dDelegate)FunctionImporter.Import<jump_rel_3dDelegate>("jump_rel_3d");
            n_mark_rel = (n_mark_relDelegate)FunctionImporter.Import<n_mark_relDelegate>("n_mark_rel");
            mark_rel = (mark_relDelegate)FunctionImporter.Import<mark_relDelegate>("mark_rel");
            n_mark_rel_3d = (n_mark_rel_3dDelegate)FunctionImporter.Import<n_mark_rel_3dDelegate>("n_mark_rel_3d");
            mark_rel_3d = (mark_rel_3dDelegate)FunctionImporter.Import<mark_rel_3dDelegate>("mark_rel_3d");
            n_write_8bit_port_list = (n_write_8bit_port_listDelegate)FunctionImporter.Import<n_write_8bit_port_listDelegate>("n_write_8bit_port_list");
            write_8bit_port_list = (write_8bit_port_listDelegate)FunctionImporter.Import<write_8bit_port_listDelegate>("write_8bit_port_list");
            n_write_da_1_list = (n_write_da_1_listDelegate)FunctionImporter.Import<n_write_da_1_listDelegate>("n_write_da_1_list");
            write_da_1_list = (write_da_1_listDelegate)FunctionImporter.Import<write_da_1_listDelegate>("write_da_1_list");
            n_write_da_2_list = (n_write_da_2_listDelegate)FunctionImporter.Import<n_write_da_2_listDelegate>("n_write_da_2_list");
            write_da_2_list = (write_da_2_listDelegate)FunctionImporter.Import<write_da_2_listDelegate>("write_da_2_list");
            n_write_da_x_list = (n_write_da_x_listDelegate)FunctionImporter.Import<n_write_da_x_listDelegate>("n_write_da_x_list");
            write_da_x_list = (write_da_x_listDelegate)FunctionImporter.Import<write_da_x_listDelegate>("write_da_x_list");
            n_set_offset_list = (n_set_offset_listDelegate)FunctionImporter.Import<n_set_offset_listDelegate>("n_set_offset_list");
            set_offset_list = (set_offset_listDelegate)FunctionImporter.Import<set_offset_listDelegate>("set_offset_list");
            n_long_delay = (n_long_delayDelegate)FunctionImporter.Import<n_long_delayDelegate>("n_long_delay");
            long_delay = (long_delayDelegate)FunctionImporter.Import<long_delayDelegate>("long_delay");
            n_laser_on_list = (n_laser_on_listDelegate)FunctionImporter.Import<n_laser_on_listDelegate>("n_laser_on_list");
            laser_on_list = (laser_on_listDelegate)FunctionImporter.Import<laser_on_listDelegate>("laser_on_list");
            n_set_jump_speed = (n_set_jump_speedDelegate)FunctionImporter.Import<n_set_jump_speedDelegate>("n_set_jump_speed");
            set_jump_speed = (set_jump_speedDelegate)FunctionImporter.Import<set_jump_speedDelegate>("set_jump_speed");
            n_set_mark_speed = (n_set_mark_speedDelegate)FunctionImporter.Import<n_set_mark_speedDelegate>("n_set_mark_speed");
            set_mark_speed = (set_mark_speedDelegate)FunctionImporter.Import<set_mark_speedDelegate>("set_mark_speed");
            n_set_laser_delays = (n_set_laser_delaysDelegate)FunctionImporter.Import<n_set_laser_delaysDelegate>("n_set_laser_delays");
            set_laser_delays = (set_laser_delaysDelegate)FunctionImporter.Import<set_laser_delaysDelegate>("set_laser_delays");
            n_set_scanner_delays = (n_set_scanner_delaysDelegate)FunctionImporter.Import<n_set_scanner_delaysDelegate>("n_set_scanner_delays");
            set_scanner_delays = (set_scanner_delaysDelegate)FunctionImporter.Import<set_scanner_delaysDelegate>("set_scanner_delays");
            n_set_list_jump = (n_set_list_jumpDelegate)FunctionImporter.Import<n_set_list_jumpDelegate>("n_set_list_jump");
            set_list_jump = (set_list_jumpDelegate)FunctionImporter.Import<set_list_jumpDelegate>("set_list_jump");
            n_list_call = (n_list_callDelegate)FunctionImporter.Import<n_list_callDelegate>("n_list_call");
            list_call = (list_callDelegate)FunctionImporter.Import<list_callDelegate>("list_call");
            n_list_return = (n_list_returnDelegate)FunctionImporter.Import<n_list_returnDelegate>("n_list_return");
            list_return = (list_returnDelegate)FunctionImporter.Import<list_returnDelegate>("list_return");
            n_z_out_list = (n_z_out_listDelegate)FunctionImporter.Import<n_z_out_listDelegate>("n_z_out_list");
            z_out_list = (z_out_listDelegate)FunctionImporter.Import<z_out_listDelegate>("z_out_list");
            n_set_standby_list = (n_set_standby_listDelegate)FunctionImporter.Import<n_set_standby_listDelegate>("n_set_standby_list");
            set_standby_list = (set_standby_listDelegate)FunctionImporter.Import<set_standby_listDelegate>("set_standby_list");
            n_timed_jump_abs = (n_timed_jump_absDelegate)FunctionImporter.Import<n_timed_jump_absDelegate>("n_timed_jump_abs");
            timed_jump_abs = (timed_jump_absDelegate)FunctionImporter.Import<timed_jump_absDelegate>("timed_jump_abs");
            n_timed_mark_abs = (n_timed_mark_absDelegate)FunctionImporter.Import<n_timed_mark_absDelegate>("n_timed_mark_abs");
            timed_mark_abs = (timed_mark_absDelegate)FunctionImporter.Import<timed_mark_absDelegate>("timed_mark_abs");
            n_timed_jump_rel = (n_timed_jump_relDelegate)FunctionImporter.Import<n_timed_jump_relDelegate>("n_timed_jump_rel");
            timed_jump_rel = (timed_jump_relDelegate)FunctionImporter.Import<timed_jump_relDelegate>("timed_jump_rel");
            n_timed_mark_rel = (n_timed_mark_relDelegate)FunctionImporter.Import<n_timed_mark_relDelegate>("n_timed_mark_rel");
            timed_mark_rel = (timed_mark_relDelegate)FunctionImporter.Import<timed_mark_relDelegate>("timed_mark_rel");
            n_set_laser_timing = (n_set_laser_timingDelegate)FunctionImporter.Import<n_set_laser_timingDelegate>("n_set_laser_timing");
            set_laser_timing = (set_laser_timingDelegate)FunctionImporter.Import<set_laser_timingDelegate>("set_laser_timing");
            n_set_wobbel = (n_set_wobbelDelegate)FunctionImporter.Import<n_set_wobbelDelegate>("n_set_wobbel");
            set_wobbel = (set_wobbelDelegate)FunctionImporter.Import<set_wobbelDelegate>("set_wobbel");
            n_set_fly_x = (n_set_fly_xDelegate)FunctionImporter.Import<n_set_fly_xDelegate>("n_set_fly_x");
            set_fly_x = (set_fly_xDelegate)FunctionImporter.Import<set_fly_xDelegate>("set_fly_x");
            n_set_fly_y = (n_set_fly_yDelegate)FunctionImporter.Import<n_set_fly_yDelegate>("n_set_fly_y");
            set_fly_y = (set_fly_yDelegate)FunctionImporter.Import<set_fly_yDelegate>("set_fly_y");
            n_write_io_port_list = (n_write_io_port_listDelegate)FunctionImporter.Import<n_write_io_port_listDelegate>("n_write_io_port_list");
            write_io_port_list = (write_io_port_listDelegate)FunctionImporter.Import<write_io_port_listDelegate>("write_io_port_list");
            n_set_wait = (n_set_waitDelegate)FunctionImporter.Import<n_set_waitDelegate>("n_set_wait");
            set_wait = (set_waitDelegate)FunctionImporter.Import<set_waitDelegate>("set_wait");
            n_simulate_ext_start = (n_simulate_ext_startDelegate)FunctionImporter.Import<n_simulate_ext_startDelegate>("n_simulate_ext_start");
            simulate_ext_start = (simulate_ext_startDelegate)FunctionImporter.Import<simulate_ext_startDelegate>("simulate_ext_start");
            n_set_pixel_line = (n_set_pixel_lineDelegate)FunctionImporter.Import<n_set_pixel_lineDelegate>("n_set_pixel_line");
            set_pixel_line = (set_pixel_lineDelegate)FunctionImporter.Import<set_pixel_lineDelegate>("set_pixel_line");
            n_set_pixel = (n_set_pixelDelegate)FunctionImporter.Import<n_set_pixelDelegate>("n_set_pixel");
            set_pixel = (set_pixelDelegate)FunctionImporter.Import<set_pixelDelegate>("set_pixel");
            n_set_extstartpos_list = (n_set_extstartpos_listDelegate)FunctionImporter.Import<n_set_extstartpos_listDelegate>("n_set_extstartpos_list");
            set_extstartpos_list = (set_extstartpos_listDelegate)FunctionImporter.Import<set_extstartpos_listDelegate>("set_extstartpos_list");
            n_laser_signal_on_list = (n_laser_signal_on_listDelegate)FunctionImporter.Import<n_laser_signal_on_listDelegate>("n_laser_signal_on_list");
            laser_signal_on_list = (laser_signal_on_listDelegate)FunctionImporter.Import<laser_signal_on_listDelegate>("laser_signal_on_list");
            n_laser_signal_off_list = (n_laser_signal_off_listDelegate)FunctionImporter.Import<n_laser_signal_off_listDelegate>("n_laser_signal_off_list");
            laser_signal_off_list = (laser_signal_off_listDelegate)FunctionImporter.Import<laser_signal_off_listDelegate>("laser_signal_off_list");
            n_set_firstpulse_killer_list = (n_set_firstpulse_killer_listDelegate)FunctionImporter.Import<n_set_firstpulse_killer_listDelegate>("n_set_firstpulse_killer_list");
            set_firstpulse_killer_list = (set_firstpulse_killer_listDelegate)FunctionImporter.Import<set_firstpulse_killer_listDelegate>("set_firstpulse_killer_list");
            n_set_io_cond_list = (n_set_io_cond_listDelegate)FunctionImporter.Import<n_set_io_cond_listDelegate>("n_set_io_cond_list");
            set_io_cond_list = (set_io_cond_listDelegate)FunctionImporter.Import<set_io_cond_listDelegate>("set_io_cond_list");
            n_clear_io_cond_list = (n_clear_io_cond_listDelegate)FunctionImporter.Import<n_clear_io_cond_listDelegate>("n_clear_io_cond_list");
            clear_io_cond_list = (clear_io_cond_listDelegate)FunctionImporter.Import<clear_io_cond_listDelegate>("clear_io_cond_list");
            n_list_jump_cond = (n_list_jump_condDelegate)FunctionImporter.Import<n_list_jump_condDelegate>("n_list_jump_cond");
            list_jump_cond = (list_jump_condDelegate)FunctionImporter.Import<list_jump_condDelegate>("list_jump_cond");
            n_list_call_cond = (n_list_call_condDelegate)FunctionImporter.Import<n_list_call_condDelegate>("n_list_call_cond");
            list_call_cond = (list_call_condDelegate)FunctionImporter.Import<list_call_condDelegate>("list_call_cond");
            n_save_and_restart_timer = (n_save_and_restart_timerDelegate)FunctionImporter.Import<n_save_and_restart_timerDelegate>("n_save_and_restart_timer");
            save_and_restart_timer = (save_and_restart_timerDelegate)FunctionImporter.Import<save_and_restart_timerDelegate>("save_and_restart_timer");
            n_set_matrix_list = (n_set_matrix_listDelegate)FunctionImporter.Import<n_set_matrix_listDelegate>("n_set_matrix_list");
            set_matrix_list = (set_matrix_listDelegate)FunctionImporter.Import<set_matrix_listDelegate>("set_matrix_list");
            n_set_control_mode_list = (n_set_control_mode_listDelegate)FunctionImporter.Import<n_set_control_mode_listDelegate>("n_set_control_mode_list");
            set_control_mode_list = (set_control_mode_listDelegate)FunctionImporter.Import<set_control_mode_listDelegate>("set_control_mode_list");
            n_set_defocus_list = (n_set_defocus_listDelegate)FunctionImporter.Import<n_set_defocus_listDelegate>("n_set_defocus_list");
            set_defocus_list = (set_defocus_listDelegate)FunctionImporter.Import<set_defocus_listDelegate>("set_defocus_list");
            n_set_ext_start_delay_list = (n_set_ext_start_delay_listDelegate)FunctionImporter.Import<n_set_ext_start_delay_listDelegate>("n_set_ext_start_delay_list");
            set_ext_start_delay_list = (set_ext_start_delay_listDelegate)FunctionImporter.Import<set_ext_start_delay_listDelegate>("set_ext_start_delay_list");
            n_set_wobbel_xy = (n_set_wobbel_xyDelegate)FunctionImporter.Import<n_set_wobbel_xyDelegate>("n_set_wobbel_xy");
            set_wobbel_xy = (set_wobbel_xyDelegate)FunctionImporter.Import<set_wobbel_xyDelegate>("set_wobbel_xy");
            n_calculate_fly = (n_calculate_flyDelegate)FunctionImporter.Import<n_calculate_flyDelegate>("n_calculate_fly");
            calculate_fly = (calculate_flyDelegate)FunctionImporter.Import<calculate_flyDelegate>("calculate_fly");
            n_select_cor_table_list = (n_select_cor_table_listDelegate)FunctionImporter.Import<n_select_cor_table_listDelegate>("n_select_cor_table_list");
            select_cor_table_list = (select_cor_table_listDelegate)FunctionImporter.Import<select_cor_table_listDelegate>("select_cor_table_list");
            n_set_fly_rot = (n_set_fly_rotDelegate)FunctionImporter.Import<n_set_fly_rotDelegate>("n_set_fly_rot");
            set_fly_rot = (set_fly_rotDelegate)FunctionImporter.Import<set_fly_rotDelegate>("set_fly_rot");
            n_fly_return = (n_fly_returnDelegate)FunctionImporter.Import<n_fly_returnDelegate>("n_fly_return");
            fly_return = (fly_returnDelegate)FunctionImporter.Import<fly_returnDelegate>("fly_return");
            n_set_trigger = (n_set_triggerDelegate)FunctionImporter.Import<n_set_triggerDelegate>("n_set_trigger");
            set_trigger = (set_triggerDelegate)FunctionImporter.Import<set_triggerDelegate>("set_trigger");
            n_arc_rel = (n_arc_relDelegate)FunctionImporter.Import<n_arc_relDelegate>("n_arc_rel");
            arc_rel = (arc_relDelegate)FunctionImporter.Import<arc_relDelegate>("arc_rel");
            n_arc_abs = (n_arc_absDelegate)FunctionImporter.Import<n_arc_absDelegate>("n_arc_abs");
            arc_abs = (arc_absDelegate)FunctionImporter.Import<arc_absDelegate>("arc_abs");
            n_time_fix = (n_time_fixDelegate)FunctionImporter.Import<n_time_fixDelegate>("n_time_fix");
            time_fix = (time_fixDelegate)FunctionImporter.Import<time_fixDelegate>("time_fix");
            n_time_fix_f = (n_time_fix_fDelegate)FunctionImporter.Import<n_time_fix_fDelegate>("n_time_fix_f");
            time_fix_f = (time_fix_fDelegate)FunctionImporter.Import<time_fix_fDelegate>("time_fix_f");
            n_mark_time = (n_mark_timeDelegate)FunctionImporter.Import<n_mark_timeDelegate>("n_mark_time");
            mark_time = (mark_timeDelegate)FunctionImporter.Import<mark_timeDelegate>("mark_time");
            n_mark_date = (n_mark_dateDelegate)FunctionImporter.Import<n_mark_dateDelegate>("n_mark_date");
            mark_date = (mark_dateDelegate)FunctionImporter.Import<mark_dateDelegate>("mark_date");
            n_mark_serial = (n_mark_serialDelegate)FunctionImporter.Import<n_mark_serialDelegate>("n_mark_serial");
            mark_serial = (mark_serialDelegate)FunctionImporter.Import<mark_serialDelegate>("mark_serial");
            n_date_check = (n_date_checkDelegate)FunctionImporter.Import<n_date_checkDelegate>("n_date_check");
            date_check = (date_checkDelegate)FunctionImporter.Import<date_checkDelegate>("date_check");
            n_flyline = (n_flylineDelegate)FunctionImporter.Import<n_flylineDelegate>("n_flyline");
            flyline = (flylineDelegate)FunctionImporter.Import<flylineDelegate>("flyline");
            n_drilling = (n_drillingDelegate)FunctionImporter.Import<n_drillingDelegate>("n_drilling");
            drilling = (drillingDelegate)FunctionImporter.Import<drillingDelegate>("drilling");
            n_regulation = (n_regulationDelegate)FunctionImporter.Import<n_regulationDelegate>("n_regulation");
            regulation = (regulationDelegate)FunctionImporter.Import<regulationDelegate>("regulation");
            n_regulation2 = (n_regulation2Delegate)FunctionImporter.Import<n_regulation2Delegate>("n_regulation2");
            regulation2 = (regulation2Delegate)FunctionImporter.Import<regulation2Delegate>("regulation2");
            n_regulation3 = (n_regulation3Delegate)FunctionImporter.Import<n_regulation3Delegate>("n_regulation3");
            regulation3 = (regulation3Delegate)FunctionImporter.Import<regulation3Delegate>("regulation3");
            n_store_encoder = (n_store_encoderDelegate)FunctionImporter.Import<n_store_encoderDelegate>("n_store_encoder");
            store_encoder = (store_encoderDelegate)FunctionImporter.Import<store_encoderDelegate>("store_encoder");
            n_fly_displacement_ret = (n_fly_displacement_retDelegate)FunctionImporter.Import<n_fly_displacement_retDelegate>("n_fly_displacement_ret");
            fly_displacement_ret = (fly_displacement_retDelegate)FunctionImporter.Import<fly_displacement_retDelegate>("fly_displacement_ret");
            usb_reinitialize = (usb_reinitializeDelegate)FunctionImporter.Import<usb_reinitializeDelegate>("usb_reinitialize");
            #endregion
        }
  }
}
